@@ -22,6 +22,7 @@ import java.util.Optional;
 import java.util.function.Consumer;
 
 import org.kie.workbench.common.dmn.api.definition.v1_1.Expression;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.literal.LiteralExpressionGrid;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.undefined.UndefinedExpressionGrid;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseGrid;
@@ -40,6 +41,8 @@ import org.uberfire.ext.wires.core.grids.client.widget.layer.GridWidgetRegistry;
 public class ExpressionEditorColumn extends DMNGridColumn<BaseGrid<? extends Expression>, Optional<BaseExpressionGrid<? extends Expression, ? extends GridData, ? extends BaseUIModelMapper>>>
         implements HasDOMElementResources {
 
+    public static final double DEFAULT_WIDTH = 200.0;
+
     public ExpressionEditorColumn(final GridWidgetRegistry registry,
                                   final HeaderMetaData headerMetaData,
                                   final double width,
@@ -118,7 +121,10 @@ public class ExpressionEditorColumn extends DMNGridColumn<BaseGrid<? extends Exp
                 .ifPresent(nestedGrid -> nestedGrid.startEditingCell(0, 0));
         cell.getValue().getValue()
                 .filter(nestedGrid -> !(nestedGrid instanceof UndefinedExpressionGrid))
-                .ifPresent(nestedGrid -> nestedGrid.selectFirstCell());
+                .ifPresent(BaseExpressionGrid::selectFirstCell);
+        cell.getValue().getValue()
+                .filter(nestedGrid -> nestedGrid instanceof LiteralExpressionGrid)
+                .ifPresent(nestedGrid -> nestedGrid.startEditingCell(0, 0));
     }
 
     protected void updateWidthOfChildren() {
