@@ -103,6 +103,7 @@ public class FunctionGrid extends BaseExpressionGrid<FunctionDefinition, DMNGrid
                         final CellEditorControlsView.Presenter cellEditorControls,
                         final ListSelectorView.Presenter listSelector,
                         final TranslationService translationService,
+                        final boolean isOnlyVisualChangeAllowed,
                         final int nesting,
                         final Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier,
                         final Supplier<ExpressionEditorDefinitions> supplementaryEditorDefinitionsSupplier,
@@ -127,6 +128,7 @@ public class FunctionGrid extends BaseExpressionGrid<FunctionDefinition, DMNGrid
               cellEditorControls,
               listSelector,
               translationService,
+              isOnlyVisualChangeAllowed,
               nesting);
         this.expressionEditorDefinitionsSupplier = expressionEditorDefinitionsSupplier;
         this.supplementaryEditorDefinitionsSupplier = supplementaryEditorDefinitionsSupplier;
@@ -150,6 +152,7 @@ public class FunctionGrid extends BaseExpressionGrid<FunctionDefinition, DMNGrid
         return new FunctionUIModelMapper(this,
                                          this::getModel,
                                          getExpression(),
+                                         () -> isOnlyVisualChangeAllowed,
                                          expressionEditorDefinitionsSupplier,
                                          supplementaryEditorDefinitionsSupplier,
                                          listSelector,
@@ -195,11 +198,13 @@ public class FunctionGrid extends BaseExpressionGrid<FunctionDefinition, DMNGrid
     }
 
     @Override
-    protected void initialiseUiModel() {
-        getExpression().get().ifPresent(e -> {
-            model.appendRow(new ExpressionEditorGridRow());
-            uiModelMapper.fromDMNModel(0, 1);
-        });
+    public void initialiseUiRows() {
+        getExpression().get().ifPresent(e -> model.appendRow(new ExpressionEditorGridRow()));
+    }
+
+    @Override
+    public void initialiseUiCells() {
+        getExpression().get().ifPresent(e -> uiModelMapper.fromDMNModel(0, 1));
     }
 
     @Override
@@ -333,8 +338,10 @@ public class FunctionGrid extends BaseExpressionGrid<FunctionDefinition, DMNGrid
                                                              kind,
                                                              expression,
                                                              (editor) -> {
-                                                                 resize(BaseExpressionGrid.RESIZE_EXISTING_MINIMUM);
-                                                                 editor.ifPresent(BaseExpressionGrid::selectFirstCell);
+                                                                 editor.ifPresent(e -> {
+                                                                     e.resize(BaseExpressionGrid.RESIZE_EXISTING);
+                                                                     e.selectFirstCell();
+                                                                 });
                                                              },
                                                              () -> {
                                                                  resize(BaseExpressionGrid.RESIZE_EXISTING_MINIMUM);
@@ -346,6 +353,7 @@ public class FunctionGrid extends BaseExpressionGrid<FunctionDefinition, DMNGrid
                                                                                                Optional.empty(),
                                                                                                getExpression().get().get(),
                                                                                                hasName,
+                                                                                               isOnlyVisualChangeAllowed,
                                                                                                nesting + 1);
                                                                  return editor;
                                                              }));
@@ -372,12 +380,6 @@ public class FunctionGrid extends BaseExpressionGrid<FunctionDefinition, DMNGrid
         });
     }
 
-    @Override
-    public void doAfterSelectionChange(final int uiRowIndex,
-                                       final int uiColumnIndex) {
-        selectExpressionEditorFirstCell(0, 1);
-    }
-
     @Override
     public void doAfterHeaderSelectionChange(final int uiHeaderRowIndex,
                                              final int uiHeaderColumnIndex) {
