@@ -41,16 +41,18 @@ public class LiteralExpressionUIModelMapper extends BaseUIModelMapper<LiteralExp
     @Override
     public void fromDMNModel(final int rowIndex,
                              final int columnIndex) {
-        dmnModel.get().ifPresent(literalExpression -> uiModel.get().setCell(rowIndex,
-                                                                            columnIndex,
-                                                                            () -> new LiteralExpressionCell<>(new BaseGridCellValue<>(literalExpression.getText()),
-                                                                                                              listSelector)));
+        dmnModel.get().ifPresent(literalExpression -> {
+            uiModel.get().setCell(rowIndex,
+                                  columnIndex,
+                                  () -> new LiteralExpressionCell<>(new BaseGridCellValue<>(literalExpression.getText().getValue()),
+                                                                    listSelector));
+        });
     }
 
     @Override
     public void toDMNModel(final int rowIndex,
                            final int columnIndex,
                            final Supplier<Optional<GridCellValue<?>>> cell) {
-        dmnModel.get().ifPresent(literalExpression -> literalExpression.setText(cell.get().orElse(new BaseGridCellValue<>("")).getValue().toString()));
+        dmnModel.get().ifPresent(literalExpression -> literalExpression.getText().setValue((String) cell.get().orElse(new BaseGridCellValue<>("")).getValue()));
     }
 }
