@@ -16,67 +16,84 @@
 
 package org.kie.workbench.common.dmn.client.graph;
 
+import java.util.List;
 import java.util.Optional;
-import java.util.stream.StreamSupport;
+import java.util.function.Function;
 
 import javax.enterprise.context.Dependent;
 import javax.inject.Inject;
 
-import org.kie.workbench.common.dmn.api.definition.v1_1.DMNDiagram;
+import org.kie.workbench.common.dmn.api.definition.v1_1.DRGElement;
 import org.kie.workbench.common.dmn.api.definition.v1_1.Definitions;
+import org.kie.workbench.common.dmn.api.graph.DMNDiagramUtils;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.CanvasHandler;
 import org.kie.workbench.common.stunner.core.client.session.ClientSession;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
-import org.kie.workbench.common.stunner.core.graph.Graph;
-import org.kie.workbench.common.stunner.core.graph.Node;
-import org.kie.workbench.common.stunner.core.graph.content.definition.Definition;
 
 @Dependent
 public class DMNGraphUtils {
 
-    private static Definitions NONE = null;
+    private static Definitions NO_DEFINITIONS = null;
+
+    private static Diagram NO_DIAGRAM = null;
+
+    private static CanvasHandler NO_CANVAS_HANDLER = null;
 
     private SessionManager sessionManager;
 
+    private DMNDiagramUtils dmnDiagramUtils;
+
     public DMNGraphUtils() {
         //CDI proxy
     }
 
     @Inject
-    public DMNGraphUtils(final SessionManager sessionManager) {
+    public DMNGraphUtils(final SessionManager sessionManager,
+                         final DMNDiagramUtils dmnDiagramUtils) {
         this.sessionManager = sessionManager;
+        this.dmnDiagramUtils = dmnDiagramUtils;
     }
 
     public Definitions getDefinitions() {
         return getCurrentSession()
                 .map(clientSession -> {
                     return getCanvasHandler(clientSession)
-                            .map(canvasHandler -> getDefinitions(canvasHandler.getDiagram()))
-                            .orElse(NONE);
+                            .map(canvasHandler -> dmnDiagramUtils.getDefinitions(canvasHandler.getDiagram()))
+                            .orElse(NO_DEFINITIONS);
                 })
-                .orElse(NONE);
+                .orElse(NO_DEFINITIONS);
+    }
+
+    public Diagram getDiagram() {
+        return getCurrentSession()
+                .map(clientSession -> {
+                    return getCanvasHandler(clientSession)
+                            .map((Function<CanvasHandler, Diagram>) CanvasHandler::getDiagram)
+                            .orElse(NO_DIAGRAM);
+                })
+                .orElse(NO_DIAGRAM);
+    }
+
+    public CanvasHandler getCanvasHandler() {
+        return getCurrentSession()
+                .map(clientSession -> getCanvasHandler(clientSession).orElse(NO_CANVAS_HANDLER))
+                .orElse(NO_CANVAS_HANDLER);
     }
 
-    @SuppressWarnings("unchecked")
     public Definitions getDefinitions(final Diagram diagram) {
-
-        final Graph<?, Node> graph = diagram.getGraph();
-
-        return StreamSupport
-                .stream(graph.nodes().spliterator(), false)
-                .map(Node::getContent)
-                .filter(c -> c instanceof Definition)
-                .map(c -> (Definition) c)
-                .map(Definition::getDefinition)
-                .filter(d -> d instanceof DMNDiagram)
-                .map(d -> (DMNDiagram) d)
-                .findFirst()
-                .map(DMNDiagram::getDefinitions)
-                .orElse(NONE);
+        return dmnDiagramUtils.getDefinitions(diagram);
     }
 
-    private Optional<ClientSession> getCurrentSession() {
+    public List<DRGElement> getDRGElements() {
+        return getDRGElements(getDiagram());
+    }
+
+    public List<DRGElement> getDRGElements(final Diagram diagram) {
+        return dmnDiagramUtils.getNodes(diagram);
+    }
+
+    public Optional<ClientSession> getCurrentSession() {
         return Optional.ofNullable(sessionManager.getCurrentSession());
     }
 
