@@ -58,6 +58,12 @@ public class DMNEditorConstants {
     @TranslationKey(defaultValue = "")
     public static final String LiteralExpression_EditExpression = "LiteralExpression.EditExpression";
 
+    @TranslationKey(defaultValue = "")
+    public static final String ContextEditor_Header = "ContextEditor.Header";
+
+    @TranslationKey(defaultValue = "")
+    public static final String ContextEditor_InsertContextEntry = "ContextEditor.InsertContextEntry";
+
     @TranslationKey(defaultValue = "")
     public static final String ContextEditor_InsertContextEntryAbove = "ContextEditor.InsertContextEntryAbove";
 
@@ -73,6 +79,9 @@ public class DMNEditorConstants {
     @TranslationKey(defaultValue = "")
     public static final String ContextEditor_EditContextEntry = "ContextEditor.EditContextEntry";
 
+    @TranslationKey(defaultValue = "")
+    public static final String RelationEditor_HeaderRows = "RelationEditor.HeaderRows";
+
     @TranslationKey(defaultValue = "")
     public static final String RelationEditor_InsertRowAbove = "RelationEditor.InsertRowAbove";
 
@@ -82,6 +91,9 @@ public class DMNEditorConstants {
     @TranslationKey(defaultValue = "")
     public static final String RelationEditor_DeleteRow = "RelationEditor.DeleteRow";
 
+    @TranslationKey(defaultValue = "")
+    public static final String RelationEditor_HeaderColumns = "RelationEditor.HeaderColumns";
+
     @TranslationKey(defaultValue = "")
     public static final String RelationEditor_InsertColumnLeft = "RelationEditor.InsertColumnLeft";
 
@@ -94,6 +106,12 @@ public class DMNEditorConstants {
     @TranslationKey(defaultValue = "")
     public static final String RelationEditor_EditRelation = "RelationEditor.EditRelation";
 
+    @TranslationKey(defaultValue = "")
+    public static final String InvocationEditor_Header = "InvocationEditor.Header";
+
+    @TranslationKey(defaultValue = "")
+    public static final String InvocationEditor_InsertParameter = "InvocationEditor.InsertParameter";
+
     @TranslationKey(defaultValue = "")
     public static final String InvocationEditor_InsertParameterAbove = "InvocationEditor.InsertParameterAbove";
 
@@ -140,7 +158,7 @@ public class DMNEditorConstants {
     public static final String DecisionTableEditor_DescriptionColumnHeader = "DecisionTableEditor.DescriptionColumnHeader";
 
     @TranslationKey(defaultValue = "")
-    public static final String DecisionTableEditor_OutputClauseHeader = "DecisionTableEditor.OutputClauseHeader";
+    public static final String DecisionTableEditor_DecisionRuleHeader = "DecisionTableEditor.DecisionRuleHeader";
 
     @TranslationKey(defaultValue = "")
     public static final String DecisionTableEditor_InsertDecisionRuleAbove = "DecisionTableEditor.InsertDecisionRuleAbove";
@@ -154,6 +172,9 @@ public class DMNEditorConstants {
     @TranslationKey(defaultValue = "")
     public static final String DecisionTableEditor_DuplicateDecisionRule = "DecisionTableEditor.DuplicateDecisionRule";
 
+    @TranslationKey(defaultValue = "")
+    public static final String DecisionTableEditor_InputClauseHeader = "DecisionTableEditor.InputClauseHeader";
+
     @TranslationKey(defaultValue = "")
     public static final String DecisionTableEditor_InsertInputClauseLeft = "DecisionTableEditor.InsertInputClauseLeft";
 
@@ -163,6 +184,9 @@ public class DMNEditorConstants {
     @TranslationKey(defaultValue = "")
     public static final String DecisionTableEditor_DeleteInputClause = "DecisionTableEditor.DeleteInputClause";
 
+    @TranslationKey(defaultValue = "")
+    public static final String DecisionTableEditor_OutputClauseHeader = "DecisionTableEditor.OutputClauseHeader";
+
     @TranslationKey(defaultValue = "")
     public static final String DecisionTableEditor_InsertOutputClauseLeft = "DecisionTableEditor.InsertOutputClauseLeft";
 
@@ -333,4 +357,64 @@ public class DMNEditorConstants {
 
     @TranslationKey(defaultValue = "")
     public static final String DayTimeValueConverter_Second = "DayTimeValueConverter.Second";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DecisionComponentsView_EnterText = "DecisionComponentsView.EnterText";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DecisionComponentsItemView_DuplicatedNode = "DecisionComponentsItemView.DuplicatedNode";
+
+    @TranslationKey(defaultValue = "")
+    public static final String LiteralExpressionPMMLDocumentEditorDefinition_Placeholder = "LiteralExpressionPMMLDocumentEditorDefinition.Placeholder";
+
+    @TranslationKey(defaultValue = "")
+    public static final String LiteralExpressionPMMLDocumentModelEditorDefinition_Placeholder = "LiteralExpressionPMMLDocumentModelEditorDefinition.Placeholder";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationI18n_DmnModelDocumentation = "DMNDocumentationI18n.DmnModelDocumentation";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationI18n_GeneratedOn = "DMNDocumentationI18n.GeneratedOn";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationI18n_GeneratedBy = "DMNDocumentationI18n.GeneratedBy";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationI18n_GeneratedFrom = "DMNDocumentationI18n.GeneratedFrom";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationI18n_Namespace = "DMNDocumentationI18n.Namespace";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationI18n_TableOfContents = "DMNDocumentationI18n.TableOfContents";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationI18n_DmnModel = "DMNDocumentationI18n.DmnModel";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationI18n_DataTypes = "DMNDocumentationI18n.DataTypes";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationI18n_DrdComponents = "DMNDocumentationI18n.DrdComponents";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationI18n_NoDataTypes = "DMNDocumentationI18n.NoDataTypes";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationI18n_NoDRDs = "DMNDocumentationI18n.NoDRDs";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationI18n_DiagramDoesNotHaveElements = "DMNDocumentationI18n.DiagramDoesNotHaveElements";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationFactory_NoFileName = "DMNDocumentationFactory.NoFileName";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationFactory_Constraints = "DMNDocumentationFactory.Constraints";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationFactory_ListYes = "DMNDocumentationFactory.ListYes";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DMNDocumentationFactory_Structure = "DMNDocumentationFactory.Structure";
 }
