@@ -28,6 +28,8 @@ import org.kie.workbench.common.dmn.api.definition.HasName;
 import org.kie.workbench.common.dmn.api.definition.v1_1.Expression;
 import org.kie.workbench.common.dmn.client.commands.factory.DefaultCanvasCommandFactory;
 import org.kie.workbench.common.dmn.client.editors.expressions.mocks.MockHasDOMElementResourcesHeaderMetaData;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.function.supplementary.pmml.LiteralExpressionPMMLGrid;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.literal.LiteralExpressionGrid;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.undefined.UndefinedExpressionGrid;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseGrid;
@@ -387,6 +389,32 @@ public class ExpressionEditorColumnTest {
         verify(contextGrid).selectFirstCell();
     }
 
+    @Test
+    public void testEditNestedLiteralExpressionGrid() {
+        final GridCell<Optional<BaseExpressionGrid<? extends Expression, ? extends GridData, ? extends BaseUIModelMapper>>> cell = mock(GridCell.class);
+        final GridCellValue<Optional<BaseExpressionGrid<? extends Expression, ? extends GridData, ? extends BaseUIModelMapper>>> cellValue = mock(GridCellValue.class);
+        final LiteralExpressionGrid leGrid = mock(LiteralExpressionGrid.class);
+        when(cell.getValue()).thenReturn(cellValue);
+        when(cellValue.getValue()).thenReturn(Optional.of(leGrid));
+
+        column.edit(cell, null, null);
+
+        verify(leGrid).startEditingCell(0, 0);
+    }
+
+    @Test
+    public void testEditNestedLiteralExpressionPMMLGrid() {
+        final GridCell<Optional<BaseExpressionGrid<? extends Expression, ? extends GridData, ? extends BaseUIModelMapper>>> cell = mock(GridCell.class);
+        final GridCellValue<Optional<BaseExpressionGrid<? extends Expression, ? extends GridData, ? extends BaseUIModelMapper>>> cellValue = mock(GridCellValue.class);
+        final LiteralExpressionPMMLGrid leGrid = mock(LiteralExpressionPMMLGrid.class);
+        when(cell.getValue()).thenReturn(cellValue);
+        when(cellValue.getValue()).thenReturn(Optional.of(leGrid));
+
+        column.edit(cell, null, null);
+
+        verify(leGrid).startEditingCell(0, 0);
+    }
+
     @Test
     public void testHeaderDOMElementsAreDestroyed() {
         final MockHasDOMElementResourcesHeaderMetaData mockHeaderMetaData = mock(MockHasDOMElementResourcesHeaderMetaData.class);
@@ -453,7 +481,7 @@ public class ExpressionEditorColumnTest {
             }
 
             @Override
-            protected void initialiseUiColumns() {
+            public void initialiseUiColumns() {
                 for (double width : widthOfCells) {
                     model.appendColumn(new DMNGridColumn<BaseGrid<Expression>, Object>(headerMetaData,
                                                                                        gridColumnRenderer,
@@ -466,7 +494,12 @@ public class ExpressionEditorColumnTest {
             }
 
             @Override
-            protected void initialiseUiModel() {
+            public void initialiseUiRows() {
+                //Nothing for this test
+            }
+
+            @Override
+            public void initialiseUiCells() {
                 //Nothing for this test
             }
 
