@@ -26,11 +26,12 @@ import org.junit.runner.RunWith;
 import org.kie.workbench.common.dmn.api.definition.v1_1.Import;
 import org.kie.workbench.common.dmn.api.property.dmn.Name;
 import org.kie.workbench.common.dmn.client.editors.common.messages.FlashMessage;
-import org.kie.workbench.common.dmn.client.editors.included.IncludedModel;
+import org.kie.workbench.common.dmn.client.editors.included.BaseIncludedModelActiveRecord;
 import org.kie.workbench.common.dmn.client.editors.included.imports.ImportFactory;
 import org.kie.workbench.common.dmn.client.editors.included.imports.IncludedModelsIndex;
 import org.kie.workbench.common.dmn.client.editors.included.imports.IncludedModelsPageStateProviderImpl;
 import org.kie.workbench.common.dmn.client.editors.included.imports.messages.IncludedModelErrorMessageFactory;
+import org.kie.workbench.common.stunner.core.client.ManagedInstanceStub;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Mock;
 import org.uberfire.mocks.EventSourceMock;
@@ -72,19 +73,31 @@ public class ImportRecordEngineTest {
     private ItemDefinitionHandler itemDefinitionHandler;
 
     @Mock
-    private DRGElementHandler drgElementHandler;
+    private DMNIncludedModelHandler dmnIncludedModelHandler;
+
+    @Mock
+    private PMMLIncludedModelHandler pmmlIncludedModelHandler;
+
+    private ManagedInstanceStub<DRGElementHandler> drgElementHandlers;
 
     private ImportRecordEngine recordEngine;
 
     @Before
     public void setup() {
-        recordEngine = spy(new ImportRecordEngine(stateProvider, includedModelsIndex, messageFactory, importFactory, flashMessageEvent, definitionsHandler, itemDefinitionHandler, drgElementHandler));
+        drgElementHandlers = new ManagedInstanceStub<>(itemDefinitionHandler, dmnIncludedModelHandler, pmmlIncludedModelHandler);
+        recordEngine = spy(new ImportRecordEngine(stateProvider,
+                                                  includedModelsIndex,
+                                                  messageFactory,
+                                                  importFactory,
+                                                  flashMessageEvent,
+                                                  definitionsHandler,
+                                                  drgElementHandlers));
     }
 
     @Test
     public void testUpdateWhenIncludedModelIsValid() {
 
-        final IncludedModel record = mock(IncludedModel.class);
+        final BaseIncludedModelActiveRecord record = mock(BaseIncludedModelActiveRecord.class);
         final ArgumentCaptor<Name> nameCaptor = ArgumentCaptor.forClass(Name.class);
         final Import anImport = mock(Import.class);
         final String name = "name";
@@ -95,13 +108,13 @@ public class ImportRecordEngineTest {
         when(includedModelsIndex.getImport(record)).thenReturn(anImport);
         when(anImport.getName()).thenReturn(new Name(oldName));
 
-        final List<IncludedModel> actualResult = recordEngine.update(record);
-        final List<IncludedModel> expectedResult = singletonList(record);
+        final List<BaseIncludedModelActiveRecord> actualResult = recordEngine.update(record);
+        final List<BaseIncludedModelActiveRecord> expectedResult = singletonList(record);
 
         verify(anImport).setName(nameCaptor.capture());
-        verify(definitionsHandler).update(oldName, record);
         verify(itemDefinitionHandler).update(oldName, name);
-        verify(drgElementHandler).update(oldName, name);
+        verify(dmnIncludedModelHandler).update(oldName, name);
+        verify(pmmlIncludedModelHandler).update(oldName, name);
 
         final Name actualName = nameCaptor.getValue();
         final Name expectedName = new Name(name);
@@ -113,7 +126,7 @@ public class ImportRecordEngineTest {
     @Test
     public void testUpdateWhenIncludedModelIsNotValid() {
 
-        final IncludedModel record = mock(IncludedModel.class);
+        final BaseIncludedModelActiveRecord record = mock(BaseIncludedModelActiveRecord.class);
         final Import anImport = mock(Import.class);
 
         when(record.isValid()).thenReturn(false);
@@ -127,7 +140,7 @@ public class ImportRecordEngineTest {
     @Test
     public void testDestroy() {
 
-        final IncludedModel record = mock(IncludedModel.class);
+        final BaseIncludedModelActiveRecord record = mock(BaseIncludedModelActiveRecord.class);
         final Import import1 = mock(Import.class);
         final Import import2 = mock(Import.class);
         final List<Import> expectedImports = singletonList(import1);
@@ -138,12 +151,13 @@ public class ImportRecordEngineTest {
         when(includedModelsIndex.getImport(record)).thenReturn(import2);
         when(stateProvider.getImports()).thenReturn(actualImports);
 
-        final List<IncludedModel> actualResult = recordEngine.destroy(record);
-        final List<IncludedModel> expectedResult = singletonList(record);
+        final List<BaseIncludedModelActiveRecord> actualResult = recordEngine.destroy(record);
+        final List<BaseIncludedModelActiveRecord> expectedResult = singletonList(record);
 
         verify(definitionsHandler).destroy(record);
         verify(itemDefinitionHandler).destroy(name);
-        verify(drgElementHandler).destroy(name);
+        verify(dmnIncludedModelHandler).destroy(name);
+        verify(pmmlIncludedModelHandler).destroy(name);
         assertEquals(expectedImports, actualImports);
         assertEquals(expectedResult, actualResult);
     }
@@ -151,7 +165,7 @@ public class ImportRecordEngineTest {
     @Test
     public void testIsValidWhenNameIsUnique() {
 
-        final IncludedModel record = mock(IncludedModel.class);
+        final BaseIncludedModelActiveRecord record = mock(BaseIncludedModelActiveRecord.class);
         final Import import1 = mock(Import.class);
         final Import import2 = mock(Import.class);
         final Name name1 = mock(Name.class);
@@ -177,7 +191,7 @@ public class ImportRecordEngineTest {
     @Test
     public void testIsValidWhenNameIsNotUnique() {
 
-        final IncludedModel record = mock(IncludedModel.class);
+        final BaseIncludedModelActiveRecord record = mock(BaseIncludedModelActiveRecord.class);
         final Import import1 = mock(Import.class);
         final Import import2 = mock(Import.class);
         final Name name1 = mock(Name.class);
@@ -203,7 +217,7 @@ public class ImportRecordEngineTest {
     @Test
     public void testIsValidWhenNameIsBlank() {
 
-        final IncludedModel record = mock(IncludedModel.class);
+        final BaseIncludedModelActiveRecord record = mock(BaseIncludedModelActiveRecord.class);
         final Import anImport = mock(Import.class);
         final Name name = mock(Name.class);
         final FlashMessage flashMessage = mock(FlashMessage.class);
@@ -225,7 +239,7 @@ public class ImportRecordEngineTest {
     @Test
     public void testIsValidWhenNameIsUnchanged() {
 
-        final IncludedModel record = mock(IncludedModel.class);
+        final BaseIncludedModelActiveRecord record = mock(BaseIncludedModelActiveRecord.class);
         final Import import1 = mock(Import.class);
         final Import import2 = mock(Import.class);
         final Name name1 = mock(Name.class);
@@ -251,7 +265,7 @@ public class ImportRecordEngineTest {
     @Test
     public void testCreate() {
 
-        final IncludedModel record = mock(IncludedModel.class);
+        final BaseIncludedModelActiveRecord record = mock(BaseIncludedModelActiveRecord.class);
         final Import import1 = mock(Import.class);
         final Import import2 = mock(Import.class);
         final Import import3 = mock(Import.class);
@@ -261,8 +275,8 @@ public class ImportRecordEngineTest {
         when(importFactory.makeImport(record)).thenReturn(import3);
         when(stateProvider.getImports()).thenReturn(actualImports);
 
-        final List<IncludedModel> actualResult = recordEngine.create(record);
-        final List<IncludedModel> expectedResult = singletonList(record);
+        final List<BaseIncludedModelActiveRecord> actualResult = recordEngine.create(record);
+        final List<BaseIncludedModelActiveRecord> expectedResult = singletonList(record);
 
         verify(definitionsHandler).create(record);
         assertEquals(expectedImports, actualImports);
