@@ -80,6 +80,9 @@ public abstract class AbstractFieldElementProcessor implements FormElementProces
             }
             field.setLabel(label);
 
+            String helpMessage = context.getI18nHelper().getTranslation(element.getHelpMessageKey());
+            field.setHelpMessage(helpMessage);
+
             field.setRequired(element.isRequired());
             field.setReadOnly(element.isReadOnly());
 
