@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -17,12 +17,16 @@
 package org.kie.workbench.common.forms.data.modeller.client.resources.i18n;
 
 import org.jboss.errai.ui.shared.api.annotations.TranslationKey;
+import org.kie.workbench.common.forms.data.modeller.model.DataObjectFormModel;
 
 public interface DataModellerIntegrationConstants {
 
-    @TranslationKey( defaultValue = "Data Object")
-    String DataObject = "DataObjectFormModelCreationPresenter.DataObject";
+    @TranslationKey(defaultValue = "Data Object")
+    String DataObject = DataObjectFormModel.class.getName();
 
-    @TranslationKey( defaultValue = "There's no Data Object selected")
-    public static final String InvalidDataObject = "DataObjectFormModelCreationPresenter.InvalidDataObject";
+    @TranslationKey(defaultValue = "There's no Data Object selected")
+    String InvalidDataObject = "DataObjectFormModelCreationPresenter.InvalidDataObject";
+
+    @TranslationKey(defaultValue = " (dependency)")
+    String DataObjectFormModelCreationViewImplDependency = "DataObjectFormModelCreationViewImpl.Dependency";
 }
