@@ -21,14 +21,10 @@ import java.io.FileOutputStream;
 import java.net.URL;
 import java.nio.file.FileSystems;
 import java.nio.file.SimpleFileVisitor;
-import java.util.Collection;
-import java.util.Collections;
-import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-import java.util.stream.Collectors;
 import java.util.zip.ZipEntry;
 import java.util.zip.ZipInputStream;
 import javax.annotation.PostConstruct;
@@ -41,96 +37,81 @@ import org.eclipse.jgit.api.Git;
 import org.eclipse.jgit.api.errors.GitAPIException;
 import org.guvnor.common.services.project.context.WorkspaceProjectContextChangeEvent;
 import org.guvnor.common.services.project.events.NewProjectEvent;
-import org.guvnor.common.services.project.model.Module;
-import org.guvnor.common.services.project.model.POM;
 import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.project.service.WorkspaceProjectService;
 import org.guvnor.common.services.shared.metadata.MetadataService;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
 import org.guvnor.structure.organizationalunit.OrganizationalUnitService;
-import org.guvnor.structure.repositories.EnvironmentParameters;
+import org.guvnor.structure.organizationalunit.config.RepositoryInfo;
 import org.guvnor.structure.repositories.Repository;
 import org.guvnor.structure.repositories.RepositoryCopier;
-import org.guvnor.structure.repositories.RepositoryService;
-import org.guvnor.structure.repositories.impl.git.GitRepository;
-import org.guvnor.structure.server.config.ConfigGroup;
-import org.guvnor.structure.server.config.ConfigurationFactory;
 import org.guvnor.structure.server.repositories.RepositoryFactory;
 import org.jboss.errai.bus.server.annotations.Service;
 import org.kie.soup.commons.validation.PortablePreconditions;
+import org.kie.workbench.common.screens.examples.model.Credentials;
 import org.kie.workbench.common.screens.examples.model.ExampleOrganizationalUnit;
-import org.kie.workbench.common.screens.examples.model.ExampleProject;
 import org.kie.workbench.common.screens.examples.model.ExampleRepository;
 import org.kie.workbench.common.screens.examples.model.ExamplesMetaData;
+import org.kie.workbench.common.screens.examples.model.ImportProject;
 import org.kie.workbench.common.screens.examples.service.ExamplesService;
-import org.kie.workbench.common.screens.projecteditor.model.ProjectScreenModel;
+import org.kie.workbench.common.screens.examples.validation.ImportProjectValidators;
 import org.kie.workbench.common.screens.projecteditor.service.ProjectScreenService;
 import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.uberfire.backend.server.util.Paths;
-import org.uberfire.backend.vfs.Path;
 import org.uberfire.io.IOService;
 import org.uberfire.java.nio.IOException;
-import org.uberfire.spaces.SpacesAPI;
-
-import static org.guvnor.structure.repositories.EnvironmentParameters.SCHEME;
-import static org.guvnor.structure.repositories.EnvironmentParameters.MIRROR;
-import static org.guvnor.structure.server.config.ConfigType.REPOSITORY;
 
 @Service
 @ApplicationScoped
-public class ExamplesServiceImpl implements ExamplesService {
+public class ExamplesServiceImpl extends BaseProjectImportService implements ExamplesService {
 
     private static final Logger logger = LoggerFactory.getLogger(ExamplesServiceImpl.class);
 
-    private static final String PROJECT_DESCRIPTON = "project.description";
-
     private static final String KIE_WB_PLAYGROUND_ZIP = "org/kie/kie-wb-playground/kie-wb-playground.zip";
     private final Set<Repository> clonedRepositories = new HashSet<>();
     private WorkspaceProjectService projectService;
     private IOService ioService;
-    private ConfigurationFactory configurationFactory;
     private RepositoryFactory repositoryFactory;
     private KieModuleService moduleService;
-    private RepositoryService repositoryService;
     private RepositoryCopier repositoryCopier;
     private OrganizationalUnitService ouService;
     private Event<NewProjectEvent> newProjectEvent;
     private MetadataService metadataService;
-    private SpacesAPI spaces;
     private ExampleRepository playgroundRepository;
     private ProjectScreenService projectScreenService;
-
-    public ExamplesServiceImpl() {
-        //Zero-parameter Constructor for CDI proxies
-    }
+    private ImportProjectValidators validators;
 
     @Inject
     public ExamplesServiceImpl(final @Named("ioStrategy") IOService ioService,
-                               final ConfigurationFactory configurationFactory,
                                final RepositoryFactory repositoryFactory,
                                final KieModuleService moduleService,
-                               final RepositoryService repositoryService,
                                final RepositoryCopier repositoryCopier,
                                final OrganizationalUnitService ouService,
                                final WorkspaceProjectService projectService,
                                final MetadataService metadataService,
-                               final SpacesAPI spaces,
                                final Event<NewProjectEvent> newProjectEvent,
-                               final ProjectScreenService projectScreenService) {
+                               final ProjectScreenService projectScreenService,
+                               final ImportProjectValidators validators) {
+
+        super(ioService,
+              metadataService,
+              validators,
+              moduleService,
+              projectService,
+              projectScreenService);
+
         this.ioService = ioService;
-        this.configurationFactory = configurationFactory;
         this.repositoryFactory = repositoryFactory;
         this.moduleService = moduleService;
-        this.repositoryService = repositoryService;
         this.repositoryCopier = repositoryCopier;
         this.ouService = ouService;
         this.projectService = projectService;
         this.metadataService = metadataService;
-        this.spaces = spaces;
         this.newProjectEvent = newProjectEvent;
         this.projectScreenService = projectScreenService;
+        this.validators = validators;
     }
 
     @PostConstruct
@@ -203,7 +184,7 @@ public class ExamplesServiceImpl implements ExamplesService {
                                          });
     }
 
-    String resolveRepositoryUrl(final String playgroundDirectoryPath) {
+    protected String resolveRepositoryUrl(final String playgroundDirectoryPath) {
         if ("\\".equals(getFileSeparator())) {
             return "file:///" + playgroundDirectoryPath.replaceAll("\\\\",
                                                                    "/");
@@ -223,33 +204,20 @@ public class ExamplesServiceImpl implements ExamplesService {
     }
 
     @Override
-    public Set<ExampleProject> getProjects(final ExampleRepository repository) {
-        if (repository == null) {
-            return Collections.emptySet();
-        }
-        final String repositoryURL = repository.getUrl();
-        if (repositoryURL == null || repositoryURL.trim().isEmpty()) {
-            return Collections.emptySet();
-        }
-
-        // Avoid cloning playground repository multiple times
-        Repository gitRepository = resolveGitRepository(repository);
-
-        if (gitRepository == null) {
-            return Collections.emptySet();
-        }
-
-        final Set<Module> modules = moduleService.getAllModules(gitRepository.getBranch("master").get());
-        return convert(modules);
-    }
-
-    Repository resolveGitRepository(final ExampleRepository exampleRepository) {
+    protected Repository resolveGitRepository(final ExampleRepository exampleRepository) {
         if (exampleRepository.equals(playgroundRepository)) {
             return clonedRepositories.stream().filter(r -> exampleRepository.getUrl().equals(r.getEnvironment().get("origin"))).findFirst().orElseGet(() -> cloneRepository(exampleRepository.getUrl()));
         } else {
+            Credentials credentials = exampleRepository.getCredentials();
+            String username = null;
+            String password = null;
+            if (credentials != null) {
+                username = credentials.getUsername();
+                password = credentials.getPassword();
+            }
             return cloneRepository(exampleRepository.getUrl(),
-                                   exampleRepository.getUserName(),
-                                   exampleRepository.getPassword());
+                                   username,
+                                   password);
         }
     }
 
@@ -262,40 +230,17 @@ public class ExamplesServiceImpl implements ExamplesService {
     private Repository cloneRepository(final String repositoryURL,
                                        final String userName,
                                        final String password) {
-        Repository repository = null;
         try {
-            final String alias = getExampleAlias(repositoryURL);
-            final Map<String, Object> env = new HashMap<String, Object>() {{
-                put("origin",
-                    repositoryURL);
-                put(SCHEME,
-                    GitRepository.SCHEME.toString());
-                put("replaceIfExists",
-                    true);
-                put("username",
-                    userName);
-                put("password",
-                    password);
-                put(MIRROR,
-                    false);
-            }};
+            final String alias = getRepositoryAlias(repositoryURL);
+            final Map<String, Object> env = this.buildGitEnv(repositoryURL,
+                                                             userName,
+                                                             password,
+                                                             false);
 
-            final ConfigGroup repositoryConfig = configurationFactory.newConfigGroup(REPOSITORY,
-                                                                                     "system",
-                                                                                     alias,
-                                                                                     "");
-            for (final Map.Entry<String, Object> entry : env.entrySet()) {
-                repositoryConfig.addConfigItem(configurationFactory.newConfigItem(entry.getKey(),
-                                                                                  entry.getValue()));
-            }
+            final RepositoryInfo repositoryConfig = this.createConfigGroup(alias,
+                                                                           env);
 
-            repositoryConfig.addConfigItem(configurationFactory.newConfigItem(EnvironmentParameters.AVOID_INDEX,
-                                                                              "true"));
-
-            repositoryConfig.addConfigItem(configurationFactory.newConfigItem(EnvironmentParameters.SPACE,
-                                                                              "system"));
-
-            repository = repositoryFactory.newRepository(repositoryConfig);
+            Repository repository = repositoryFactory.newRepository(repositoryConfig);
             clonedRepositories.add(repository);
             return repository;
         } catch (final Exception e) {
@@ -305,135 +250,39 @@ public class ExamplesServiceImpl implements ExamplesService {
         }
     }
 
-    String getExampleAlias(final String repositoryURL) {
-        String alias = repositoryURL;
-        alias = alias.substring(alias.lastIndexOf("/") + 1);
-        final int lastDotIndex = alias.lastIndexOf('.');
-        if (lastDotIndex > 0) {
-            alias = alias.substring(0,
-                                    lastDotIndex);
-        }
-        return "examples-" + alias;
+    @Override
+    protected String getRepositoryAlias(final String repositoryURL) {
+        return "examples-" + super.getRepositoryAlias(repositoryURL);
     }
 
     String getFileSeparator() {
         return FileSystems.getDefault().getSeparator();
     }
 
-    private Set<ExampleProject> convert(final Set<Module> modules) {
-        return modules.stream()
-                .map(p -> makeExampleProject(p))
-                .collect(Collectors.toSet());
-    }
-
-    private ExampleProject makeExampleProject(final Module module) {
-        final String description = readDescription(module);
-        final List<String> tags = getTags(module);
-
-        return new ExampleProject(module.getRootPath(),
-                                  module.getModuleName(),
-                                  description,
-                                  tags);
-    }
-
-    private String readDescription(final Module module) {
-        final Path root = module.getRootPath();
-        final POM pom = module.getPom();
-        final org.uberfire.java.nio.file.Path nioRoot = Paths.convert(root);
-        final org.uberfire.java.nio.file.Path nioDescription = nioRoot.resolve(PROJECT_DESCRIPTON);
-        String description = "Example '" + module.getModuleName() + "' module";
-
-        if (ioService.exists(nioDescription)) {
-            description = ioService.readAllString(nioDescription);
-        } else if (pom != null
-                && pom.getDescription() != null
-                && !pom.getDescription().isEmpty()) {
-            description = pom.getDescription();
-        }
-
-        if (description != null) {
-            return description.replaceAll("[\\s]+",
-                                          " ");
-        }
-
-        return description;
-    }
-
-    private List<String> getTags(final Module module) {
-        List<String> tags = metadataService.getTags(module.getPomXMLPath());
-        tags.sort(String::compareTo);
-        return tags;
-    }
-
     @Override
     public WorkspaceProjectContextChangeEvent setupExamples(final ExampleOrganizationalUnit exampleTargetOU,
-                                                            final List<ExampleProject> exampleProjects) {
+                                                            final List<ImportProject> importProjects) {
         PortablePreconditions.checkNotNull("exampleTargetOU",
                                            exampleTargetOU);
         PortablePreconditions.checkNotNull("exampleProjects",
-                                           exampleProjects);
+                                           importProjects);
         PortablePreconditions.checkCondition("Must have at least one ExampleProject",
-                                             exampleProjects.size() > 0);
+                                             importProjects.size() > 0);
 
         //Retrieve or create Organizational Unit
         final String targetOUName = exampleTargetOU.getName();
         final OrganizationalUnit targetOU = getOrganizationalUnit(targetOUName);
-
-        WorkspaceProject firstExampleProject = null;
-
-        for (final ExampleProject exampleProject : exampleProjects) {
-            try {
-                final Repository targetRepository = repositoryCopier.copy(targetOU,
-                                                                          exampleProject.getName(),
-                                                                          exampleProject.getRoot());
-
-                // Signal creation of new Project (Creation of OU and Repository, if applicable,
-                // are already handled in the corresponding services).
-                WorkspaceProject project = projectService.resolveProject(targetRepository);
-                project = renameIfNecessary(targetOU,
-                                            project);
-                newProjectEvent.fire(new NewProjectEvent(project));
-
-                //Store first new example project
-                if (firstExampleProject == null) {
-                    firstExampleProject = project;
-                }
-            } catch (IOException ioe) {
-                logger.error("Unable to create Example(s).",
-                             ioe);
-            }
-        }
-
-        return new WorkspaceProjectContextChangeEvent(firstExampleProject,
-                                                      firstExampleProject.getMainModule());
+        return this.importProjects(targetOU,
+                                   importProjects);
     }
 
-    private WorkspaceProject renameIfNecessary(final OrganizationalUnit ou,
-                                               final WorkspaceProject project) {
-
-        String name = project.getName();
-        Collection<WorkspaceProject> projectsWithSameName = projectService.getAllWorkspaceProjectsByName(ou,
-                                                                                                         name);
-
-        if (projectsWithSameName.size() > 1) {
-            name = this.projectService.createFreshProjectName(ou,
-                                                              project.getName());
-        }
-
-        if (!name.equals(project.getName())) {
-            final Path pomXMLPath = project.getMainModule().getPomXMLPath();
-            final ProjectScreenModel model = projectScreenService.load(pomXMLPath);
-            model.getPOM().setName(name);
-            projectScreenService.save(pomXMLPath,
-                                      model,
-                                      "");
-            return projectService.resolveProject(pomXMLPath);
-        }
-
-        return project;
+    @Override
+    public Set<ImportProject> getExampleProjects() {
+        ExampleRepository repos = this.getPlaygroundRepository();
+        return this.getProjects(repos);
     }
 
-    private OrganizationalUnit getOrganizationalUnit(String targetOUName) {
+    protected OrganizationalUnit getOrganizationalUnit(String targetOUName) {
         OrganizationalUnit targetOU = ouService.getOrganizationalUnit(targetOUName);
         if (targetOU == null) {
             targetOU = createOrganizationalUnit(targetOUName);
@@ -441,9 +290,8 @@ public class ExamplesServiceImpl implements ExamplesService {
         return targetOU;
     }
 
-    private OrganizationalUnit createOrganizationalUnit(final String name) {
+    protected OrganizationalUnit createOrganizationalUnit(final String name) {
         final OrganizationalUnit ou = ouService.createOrganizationalUnit(name,
-                                                                         "",
                                                                          "");
         return ou;
     }
@@ -475,4 +323,36 @@ public class ExamplesServiceImpl implements ExamplesService {
     void setPlaygroundRepository(final ExampleRepository playgroundRepository) {
         this.playgroundRepository = playgroundRepository;
     }
+
+    protected WorkspaceProjectContextChangeEvent importProjects(OrganizationalUnit targetOU,
+                                                                List<ImportProject> projects) {
+
+        WorkspaceProject firstExampleProject = null;
+
+        for (final ImportProject importProject : projects) {
+            try {
+                final Repository targetRepository = repositoryCopier.copy(targetOU,
+                                                                          "example-" + importProject.getName(),
+                                                                          importProject.getRoot());
+
+                // Signal creation of new Project (Creation of OU and Repository, if applicable,
+                // are already handled in the corresponding services).
+                WorkspaceProject project = projectService.resolveProject(targetRepository);
+                project = renameIfNecessary(targetOU,
+                                            project);
+                newProjectEvent.fire(new NewProjectEvent(project));
+
+                //Store first new example project
+                if (firstExampleProject == null) {
+                    firstExampleProject = project;
+                }
+            } catch (IOException ioe) {
+                logger.error("Unable to create Example(s).",
+                             ioe);
+            }
+        }
+
+        return new WorkspaceProjectContextChangeEvent(firstExampleProject,
+                                                      firstExampleProject.getMainModule());
+    }
 }
