@@ -34,31 +34,31 @@ import org.guvnor.common.services.project.model.POM;
 import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.project.service.WorkspaceProjectService;
 import org.guvnor.common.services.shared.metadata.MetadataService;
-import org.guvnor.structure.backend.config.ConfigurationFactoryImpl;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
 import org.guvnor.structure.organizationalunit.OrganizationalUnitService;
+import org.guvnor.structure.organizationalunit.config.RepositoryConfiguration;
+import org.guvnor.structure.organizationalunit.config.RepositoryInfo;
 import org.guvnor.structure.organizationalunit.impl.OrganizationalUnitImpl;
 import org.guvnor.structure.repositories.Branch;
 import org.guvnor.structure.repositories.EnvironmentParameters;
 import org.guvnor.structure.repositories.Repository;
 import org.guvnor.structure.repositories.RepositoryCopier;
-import org.guvnor.structure.repositories.RepositoryService;
 import org.guvnor.structure.repositories.impl.git.GitRepository;
-import org.guvnor.structure.server.config.ConfigGroup;
-import org.guvnor.structure.server.config.ConfigType;
-import org.guvnor.structure.server.config.ConfigurationFactory;
 import org.guvnor.structure.server.repositories.RepositoryFactory;
 import org.jboss.errai.security.shared.api.identity.User;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.screens.examples.model.ExampleOrganizationalUnit;
-import org.kie.workbench.common.screens.examples.model.ExampleProject;
 import org.kie.workbench.common.screens.examples.model.ExampleRepository;
 import org.kie.workbench.common.screens.examples.model.ExamplesMetaData;
+import org.kie.workbench.common.screens.examples.model.ImportProject;
+import org.kie.workbench.common.screens.examples.validation.ImportProjectValidators;
 import org.kie.workbench.common.screens.projecteditor.service.ProjectScreenService;
 import org.kie.workbench.common.services.shared.project.KieModule;
 import org.kie.workbench.common.services.shared.project.KieModuleService;
+import org.mockito.ArgumentCaptor;
+import org.mockito.Captor;
 import org.mockito.Mock;
 import org.mockito.Spy;
 import org.mockito.invocation.InvocationOnMock;
@@ -69,10 +69,12 @@ import org.uberfire.backend.vfs.PathFactory;
 import org.uberfire.io.IOService;
 import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.rpc.SessionInfo;
-import org.uberfire.spaces.Space;
-import org.uberfire.spaces.SpacesAPI;
 
 import static org.junit.Assert.*;
+import static org.kie.workbench.common.screens.examples.backend.server.ImportUtils.makeGitRepository;
+import static org.mockito.Matchers.any;
+import static org.mockito.Matchers.anyString;
+import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.*;
 
 @RunWith(MockitoJUnitRunner.class)
@@ -81,18 +83,12 @@ public class ExamplesServiceImplTest {
     @Mock
     private IOService ioService;
 
-    @Mock
-    private ConfigurationFactoryImpl configurationFactory;
-
     @Mock
     private RepositoryFactory repositoryFactory;
 
     @Mock
     private KieModuleService moduleService;
 
-    @Mock
-    private RepositoryService repositoryService;
-
     @Mock
     private RepositoryCopier repositoryCopier;
 
@@ -120,33 +116,36 @@ public class ExamplesServiceImplTest {
     private WorkspaceProjectService projectService;
 
     @Mock
-    private SpacesAPI spaces;
+    private ProjectScreenService projectScreenService;
 
     @Mock
-    private ProjectScreenService projectScreenService;
+    private ImportProjectValidators validators;
 
     private ExamplesServiceImpl service;
 
+    @Captor
+    private ArgumentCaptor<RepositoryInfo> captor;
+
     @Before
     public void setup() {
+
         service = spy(new ExamplesServiceImpl(ioService,
-                                              configurationFactory,
                                               repositoryFactory,
                                               moduleService,
-                                              repositoryService,
                                               repositoryCopier,
                                               ouService,
                                               projectService,
                                               metadataService,
-                                              spaces,
                                               newProjectEvent,
-                                              projectScreenService));
+                                              projectScreenService,
+                                              validators));
+
+        when(this.validators.getValidators()).thenReturn(new ArrayList<>());
+
         when(ouService.getOrganizationalUnits()).thenReturn(new HashSet<OrganizationalUnit>() {{
             add(new OrganizationalUnitImpl("ou1Name",
-                                           "ou1Owner",
                                            "ou1GroupId"));
             add(new OrganizationalUnitImpl("ou2Name",
-                                           "ou2Owner",
                                            "ou2GroupId"));
         }});
         when(moduleService.resolveModule(any(Path.class))).thenAnswer(new Answer<KieModule>() {
@@ -166,10 +165,6 @@ public class ExamplesServiceImplTest {
         when(sessionInfo.getId()).thenReturn("sessionId");
         when(sessionInfo.getIdentity()).thenReturn(user);
         when(user.getIdentifier()).thenReturn("user");
-        when(configurationFactory.newConfigGroup(any(ConfigType.class),
-                                                 anyString(),
-                                                 anyString(),
-                                                 anyString())).thenReturn(mock(ConfigGroup.class));
     }
 
     @Test
@@ -197,7 +192,7 @@ public class ExamplesServiceImplTest {
 
     @Test
     public void testGetProjects_NullRepository() {
-        final Set<ExampleProject> modules = service.getProjects(null);
+        final Set<ImportProject> modules = service.getProjects(null);
         assertNotNull(modules);
         assertEquals(0,
                      modules.size());
@@ -205,7 +200,7 @@ public class ExamplesServiceImplTest {
 
     @Test
     public void testGetProjects_NullRepositoryUrl() {
-        final Set<ExampleProject> modules = service.getProjects(new ExampleRepository(null));
+        final Set<ImportProject> modules = service.getProjects(new ExampleRepository(null));
         assertNotNull(modules);
         assertEquals(0,
                      modules.size());
@@ -213,7 +208,7 @@ public class ExamplesServiceImplTest {
 
     @Test
     public void testGetProjects_EmptyRepositoryUrl() {
-        final Set<ExampleProject> modules = service.getProjects(new ExampleRepository(""));
+        final Set<ImportProject> modules = service.getProjects(new ExampleRepository(""));
         assertNotNull(modules);
         assertEquals(0,
                      modules.size());
@@ -221,7 +216,7 @@ public class ExamplesServiceImplTest {
 
     @Test
     public void testGetProjects_WhiteSpaceRepositoryUrl() {
-        final Set<ExampleProject> modules = service.getProjects(new ExampleRepository("   "));
+        final Set<ImportProject> modules = service.getProjects(new ExampleRepository("   "));
         assertNotNull(modules);
         assertEquals(0,
                      modules.size());
@@ -238,22 +233,27 @@ public class ExamplesServiceImplTest {
                                                                                 "tag2"));
 
         final GitRepository repository = makeGitRepository();
-        when(repositoryFactory.newRepository(any(ConfigGroup.class))).thenReturn(repository);
+        when(repositoryFactory.newRepository(any(RepositoryInfo.class))).thenReturn(repository);
         when(moduleService.getAllModules(any(Branch.class))).thenReturn(new HashSet<Module>() {{
             add(module);
         }});
 
         service.setPlaygroundRepository(mock(ExampleRepository.class));
 
-        final Set<ExampleProject> modules = service.getProjects(new ExampleRepository("https://github.com/guvnorngtestuser1/guvnorng-playground.git"));
+        String origin = "https://github.com/guvnorngtestuser1/guvnorng-playground.git";
+        final Set<ImportProject> modules = service.getProjects(new ExampleRepository(origin));
         assertNotNull(modules);
         assertEquals(1,
                      modules.size());
-        assertTrue(modules.contains(new ExampleProject(moduleRoot,
-                                                       "module1",
-                                                       "Example 'module1' module",
-                                                       Arrays.asList("tag1",
-                                                                     "tag2"))));
+        assertTrue(modules.contains(new ImportProject(moduleRoot,
+                                                      "module1",
+                                                      "Example 'module1' module",
+                                                      origin,
+                                                      Arrays.asList("tag1",
+                                                                    "tag2"),
+                                                      null,
+                                                      Collections.emptyList(),
+                                                      false)));
     }
 
     @Test
@@ -269,20 +269,25 @@ public class ExamplesServiceImplTest {
                                                                                 "tag2"));
 
         final GitRepository repository = makeGitRepository();
-        when(repositoryFactory.newRepository(any(ConfigGroup.class))).thenReturn(repository);
+        when(repositoryFactory.newRepository(any(RepositoryInfo.class))).thenReturn(repository);
         when(moduleService.getAllModules(any(Branch.class))).thenReturn(new HashSet<Module>() {{
             add(module);
         }});
 
-        final Set<ExampleProject> modules = service.getProjects(new ExampleRepository("https://github.com/guvnorngtestuser1/guvnorng-playground.git"));
+        String origin = "https://github.com/guvnorngtestuser1/guvnorng-playground.git";
+        final Set<ImportProject> modules = service.getProjects(new ExampleRepository(origin));
         assertNotNull(modules);
         assertEquals(1,
                      modules.size());
-        assertTrue(modules.contains(new ExampleProject(moduleRoot,
-                                                       "module1",
-                                                       "This is custom description. This is a new line.",
-                                                       Arrays.asList("tag1",
-                                                                     "tag2"))));
+        assertTrue(modules.contains(new ImportProject(moduleRoot,
+                                                      "module1",
+                                                      "This is custom description. This is a new line.",
+                                                      origin,
+                                                      Arrays.asList("tag1",
+                                                                    "tag2"),
+                                                      null,
+                                                      Collections.emptyList(),
+                                                      false)));
     }
 
     @Test
@@ -299,20 +304,25 @@ public class ExamplesServiceImplTest {
                                                                                 "tag2"));
 
         final GitRepository repository = makeGitRepository();
-        when(repositoryFactory.newRepository(any(ConfigGroup.class))).thenReturn(repository);
+        when(repositoryFactory.newRepository(any(RepositoryInfo.class))).thenReturn(repository);
         when(moduleService.getAllModules(any(Branch.class))).thenReturn(new HashSet<Module>() {{
             add(module);
         }});
 
-        final Set<ExampleProject> modules = service.getProjects(new ExampleRepository("https://github.com/guvnorngtestuser1/guvnorng-playground.git"));
+        String origin = "https://github.com/guvnorngtestuser1/guvnorng-playground.git";
+        final Set<ImportProject> modules = service.getProjects(new ExampleRepository(origin));
         assertNotNull(modules);
         assertEquals(1,
                      modules.size());
-        assertTrue(modules.contains(new ExampleProject(moduleRoot,
-                                                       "module1",
-                                                       "pom description",
-                                                       Arrays.asList("tag1",
-                                                                     "tag2"))));
+        assertTrue(modules.contains(new ImportProject(moduleRoot,
+                                                      "module1",
+                                                      "pom description",
+                                                      origin,
+                                                      Arrays.asList("tag1",
+                                                                    "tag2"),
+                                                      null,
+                                                      Collections.emptyList(),
+                                                      false)));
     }
 
     @Test(expected = IllegalArgumentException.class)
@@ -330,17 +340,15 @@ public class ExamplesServiceImplTest {
     @Test(expected = IllegalStateException.class)
     public void testSetupExamples_ZeroModules() {
         service.setupExamples(mock(ExampleOrganizationalUnit.class),
-                              Collections.<ExampleProject>emptyList());
+                              Collections.emptyList());
     }
 
     @Test
     public void testSetupExamples_NewOrganizationalUnitNewRepository() {
         final ExampleOrganizationalUnit exOU = mock(ExampleOrganizationalUnit.class);
-        final ExampleProject exModule = mock(ExampleProject.class);
+        final ImportProject exModule = mock(ImportProject.class);
         doReturn("module").when(exModule).getName();
-        final List<ExampleProject> exModules = new ArrayList<ExampleProject>() {{
-            add(exModule);
-        }};
+        final List<ImportProject> exModules = Collections.singletonList(exModule);
         final OrganizationalUnit ou = mock(OrganizationalUnit.class);
         doReturn("ou").when(ou).getName();
         final GitRepository repository = mock(GitRepository.class);
@@ -358,7 +366,6 @@ public class ExamplesServiceImplTest {
 
         when(ouService.getOrganizationalUnit(eq("ou"))).thenReturn(null);
         when(ouService.createOrganizationalUnit(eq("ou"),
-                                                eq(""),
                                                 eq(""))).thenReturn(ou);
         when(repositoryCopier.copy(eq(ou),
                                    anyString(),
@@ -376,7 +383,6 @@ public class ExamplesServiceImplTest {
 
         verify(ouService,
                times(1)).createOrganizationalUnit(eq("ou"),
-                                                  eq(""),
                                                   eq(""));
         verify(repositoryCopier,
                times(1)).copy(eq(ou),
@@ -389,14 +395,12 @@ public class ExamplesServiceImplTest {
     @Test
     public void testSetupExamples_ProjectCopy() {
         final ExampleOrganizationalUnit exOU = mock(ExampleOrganizationalUnit.class);
-        final ExampleProject exProject1 = mock(ExampleProject.class);
+        final ImportProject exProject1 = mock(ImportProject.class);
         doReturn("project 1").when(exProject1).getName();
-        final ExampleProject exProject2 = mock(ExampleProject.class);
+        final ImportProject exProject2 = mock(ImportProject.class);
         doReturn("project 2").when(exProject1).getName();
-        final List<ExampleProject> exProjects = new ArrayList<ExampleProject>() {{
-            add(exProject1);
-            add(exProject2);
-        }};
+        final List<ImportProject> exProjects = Arrays.asList(exProject1,
+                                                             exProject2);
         final OrganizationalUnit ou = mock(OrganizationalUnit.class);
         doReturn("ou").when(ou).getName();
         final GitRepository repository1 = mock(GitRepository.class);
@@ -443,7 +447,6 @@ public class ExamplesServiceImplTest {
 
         verify(ouService,
                never()).createOrganizationalUnit(eq("ou"),
-                                                 eq(""),
                                                  eq(""));
         verify(repositoryCopier,
                times(2)).copy(eq(ou),
@@ -483,30 +486,23 @@ public class ExamplesServiceImplTest {
         ExampleRepository playgroundRepository = new ExampleRepository("file:///home/user/folder/.kie-wb-playground");
         service.setPlaygroundRepository(playgroundRepository);
 
-        ConfigGroup configGroup = new ConfigGroup();
-        when(configurationFactory.newConfigGroup(any(ConfigType.class),
-                                                 anyString(),
-                                                 anyString(),
-                                                 anyString())).thenReturn(configGroup);
-        doCallRealMethod().when(configurationFactory).newConfigItem(anyString(),
-                                                                    anyBoolean());
-        doCallRealMethod().when(configurationFactory).newConfigItem(anyString(),
-                                                                    anyString());
-        doCallRealMethod().when(configurationFactory).newConfigItem(anyString(),
-                                                                    any(Object.class));
+        RepositoryInfo configGroup = new RepositoryInfo("examples-.kie-wb-playground",
+                                                        false,
+                                                        new RepositoryConfiguration());
 
         Repository repository = mock(Repository.class);
-        when(repositoryFactory.newRepository(configGroup)).thenReturn(repository);
+        when(repositoryFactory.newRepository(captor.capture())).thenReturn(repository);
 
         Repository result = service.resolveGitRepository(playgroundRepository);
 
         assertEquals(repository,
                      result);
         assertEquals(false,
-                     configGroup.getConfigItem(EnvironmentParameters.MIRROR).getValue());
+                     captor.getValue().getConfiguration().get(Boolean.class,
+                                                              EnvironmentParameters.MIRROR));
 
         verify(repositoryFactory,
-               times(1)).newRepository(configGroup);
+               times(1)).newRepository(any());
     }
 
     @Test
@@ -528,19 +524,6 @@ public class ExamplesServiceImplTest {
                      result);
 
         verify(repositoryFactory,
-               never()).newRepository(any(ConfigGroup.class));
-    }
-
-    private GitRepository makeGitRepository() {
-        final GitRepository repository = new GitRepository("guvnorng-playground",
-                                                           new Space("space"));
-
-        final HashMap<String, Branch> branches = new HashMap<>();
-        branches.put("master",
-                     new Branch("master",
-                                mock(Path.class)));
-        repository.setBranches(branches);
-
-        return repository;
+               never()).newRepository(any(RepositoryInfo.class));
     }
 }
