@@ -237,10 +237,10 @@ public class LibraryConstants {
     public static final String AddProjectSuccess = "AddProjectSuccess";
 
     @TranslationKey(defaultValue = "")
-    public static final String ShowAdvancedOptions = "ShowAdvancedOptions";
+    public static final String ConfigureAdvancedOptions = "ConfigureAdvancedOptions";
 
     @TranslationKey(defaultValue = "")
-    public static final String HideAdvancedOptions = "HideAdvancedOptions";
+    public static final String RestoreAdvancedOptions = "RestoreAdvancedOptions";
 
     @TranslationKey(defaultValue = "")
     public static final String GroupId = "GroupId";
@@ -530,6 +530,9 @@ public class LibraryConstants {
     @TranslationKey(defaultValue = "")
     public static final String Test = "Test";
 
+    @TranslationKey(defaultValue = "")
+    public static final String NoBranchesWithWriteAccess = "NoBranchesWithWriteAccess";
+
     @TranslationKey(defaultValue = "")
     public static final String BranchManagementReadPermissionTooltip = "BranchManagementReadPermissionTooltip";
 
@@ -559,4 +562,19 @@ public class LibraryConstants {
 
     @TranslationKey(defaultValue = "")
     public static final String BranchSelectorSelectedBranches = "BranchSelectorSelectedBranches";
+
+    @TranslationKey(defaultValue = "")
+    public static final String OneWeekAgo = "OneWeekAgo";
+
+    @TranslationKey(defaultValue = "")
+    public static final String WeeksAgo = "WeeksAgo";
+
+    @TranslationKey(defaultValue = "")
+    public static final String Today = "Today";
+
+    @TranslationKey(defaultValue = "")
+    public static final String OneDayAgo = "OneDayAgo";
+
+    @TranslationKey(defaultValue = "")
+    public static final String DaysAgo = "DaysAgo";
 }
