@@ -128,7 +128,6 @@ public class SettingsPresenterTest {
 
         presenter.setup();
 
-        verify(presenter, times(1)).setupUsingCurrentSection();
         verify(sectionManager).init(eq(sections), any(), any());
     }
 
@@ -150,7 +149,7 @@ public class SettingsPresenterTest {
         doReturn(true).when(sectionManager).manages(any());
         doReturn(promises.resolve()).when(sectionManager).goToCurrentSection();
         doReturn(promises.resolve()).when(presenter).setupSections(any());
-        doReturn(true).when(projectController).canUpdateProject(any());
+        doReturn(promises.resolve(true)).when(projectController).canUpdateProject(any());
 
         presenter.setupUsingCurrentSection();
 
@@ -175,7 +174,7 @@ public class SettingsPresenterTest {
         doReturn(true).when(sectionManager).manages(any());
         doReturn(promises.resolve()).when(sectionManager).goToCurrentSection();
         doReturn(promises.resolve()).when(presenter).setupSections(any());
-        doReturn(false).when(projectController).canUpdateProject(any());
+        doReturn(promises.resolve(false)).when(projectController).canUpdateProject(any());
 
         presenter.setupUsingCurrentSection();
 
@@ -200,6 +199,7 @@ public class SettingsPresenterTest {
         doReturn(false).when(sectionManager).manages(eq(section));
         doReturn(promises.resolve()).when(sectionManager).goToFirstAvailable();
         doReturn(promises.resolve()).when(presenter).setupSections(any());
+        doReturn(promises.resolve(false)).when(projectController).canUpdateProject(any());
 
         presenter.setupUsingCurrentSection();
 
@@ -222,6 +222,7 @@ public class SettingsPresenterTest {
 
         doReturn(new ArrayList<>(Arrays.asList(section1, section2))).when(sectionManager).getSections();
         doReturn(promises.reject("Test")).when(presenter).setupSections(any());
+        doReturn(promises.resolve(false)).when(projectController).canUpdateProject(any());
 
         presenter.setupUsingCurrentSection();
 
@@ -300,7 +301,7 @@ public class SettingsPresenterTest {
 
     @Test
     public void testShowSaveModal() {
-        doReturn(true).when(projectController).canUpdateProject(any());
+        doReturn(promises.resolve(true)).when(projectController).canUpdateProject(any());
         doReturn(promises.resolve()).when(sectionManager).validateAll();
 
         presenter.showSaveModal();
@@ -311,7 +312,7 @@ public class SettingsPresenterTest {
 
     @Test
     public void testShowSaveModalWithoutPermission() {
-        doReturn(false).when(projectController).canUpdateProject(any());
+        doReturn(promises.resolve(false)).when(projectController).canUpdateProject(any());
         doReturn(promises.resolve()).when(sectionManager).validateAll();
 
         presenter.showSaveModal();
@@ -322,7 +323,7 @@ public class SettingsPresenterTest {
 
     @Test
     public void testShowSaveModalWithValidationError() {
-        doReturn(true).when(projectController).canUpdateProject(any());
+        doReturn(promises.resolve(true)).when(projectController).canUpdateProject(any());
         Section<ProjectScreenModel> section = newMockedSection();
         doReturn(promises.reject(section)).when(sectionManager).validateAll();
 
@@ -387,14 +388,12 @@ public class SettingsPresenterTest {
 
         doThrow(testException).when(section1).save(any(), any());
         doReturn(promises.resolve()).when(section2).save(any(), any());
-        doReturn(promises.resolve()).when(presenter).defaultErrorResolution(testException);
         doReturn(new ArrayList<>(Arrays.asList(section1, section2))).when(sectionManager).getSections();
 
         presenter.save("Test comment");
 
         verify(section1).save(eq("Test comment"), any());
         verify(section2, never()).save(any(), any());
-        verify(presenter).defaultErrorResolution(eq(testException));
         verify(presenter, never()).saveProjectScreenModel(any(), any(), any());
         verify(sectionManager, never()).resetDirtyIndicator(any());
         verify(presenter, never()).displaySuccessMessage();
@@ -437,12 +436,6 @@ public class SettingsPresenterTest {
         verify(presenter,
                never()).handlePomConcurrentUpdate(any(),
                                                   any());
-        verify(presenter,
-               never()).defaultErrorResolution(any());
-        verify(presenter,
-               never()).handleSaveProjectScreenModelError(any(),
-                                                          any(),
-                                                          any());
     }
 
     @Test
@@ -458,7 +451,6 @@ public class SettingsPresenterTest {
             fail("Promise should've not been resolved!");
             return promises.resolve();
         });
-        ;
 
         verify(projectScreenService,
                never()).save(any(),
@@ -467,12 +459,6 @@ public class SettingsPresenterTest {
                              any());
         verify(presenter).handlePomConcurrentUpdate(eq("Test comment"),
                                                     any());
-        verify(presenter,
-               never()).defaultErrorResolution(any());
-        verify(presenter,
-               never()).handleSaveProjectScreenModelError(any(),
-                                                          any(),
-                                                          any());
     }
 
     @Test
@@ -483,9 +469,6 @@ public class SettingsPresenterTest {
                                                                any(),
                                                                any(),
                                                                any());
-        doReturn(promises.resolve()).when(presenter).handleSaveProjectScreenModelError(any(),
-                                                                                       any(),
-                                                                                       any());
 
         presenter.saveProjectScreenModel("Test comment",
                                          DeploymentMode.VALIDATED,
@@ -501,48 +484,6 @@ public class SettingsPresenterTest {
         verify(presenter,
                never()).handlePomConcurrentUpdate(any(),
                                                   any());
-        verify(presenter,
-               never()).defaultErrorResolution(any());
-        verify(presenter).handleSaveProjectScreenModelError(any(),
-                                                            any(),
-                                                            any());
-    }
-
-    @Test
-    public void testHandleSaveProjectScreenModelAnyException() {
-        doReturn(promises.resolve()).when(presenter).defaultErrorResolution(any());
-        doReturn(promises.resolve()).when(presenter).handlePomConcurrentUpdate(any(),
-                                                                               any(),
-                                                                               any());
-
-        final RuntimeException testException = new RuntimeException();
-        presenter.handleSaveProjectScreenModelError("Test comment",
-                                                    null,
-                                                    testException);
-
-        verify(presenter).defaultErrorResolution(eq(testException));
-        verify(presenter,
-               never()).handlePomConcurrentUpdate(any(),
-                                                  any(),
-                                                  any());
-    }
-
-    @Test
-    public void testHandleSaveProjectScreenModelGavAlreadyExistsException() {
-        doReturn(promises.resolve()).when(presenter).defaultErrorResolution(any());
-        doReturn(promises.resolve()).when(presenter).handlePomConcurrentUpdate(any(),
-                                                                               any(),
-                                                                               any());
-
-        final GAVAlreadyExistsException testException = new GAVAlreadyExistsException();
-        presenter.handleSaveProjectScreenModelError("Test comment",
-                                                    null,
-                                                    testException);
-
-        verify(presenter, never()).defaultErrorResolution(any());
-        verify(presenter).handlePomConcurrentUpdate(eq("Test comment"),
-                                                    any(),
-                                                    eq(testException));
     }
 
     @Test
@@ -588,7 +529,7 @@ public class SettingsPresenterTest {
 
     @Test
     public void testResetWithPermission() {
-        doReturn(true).when(projectController).canUpdateProject(any());
+        doReturn(promises.resolve(true)).when(projectController).canUpdateProject(any());
         doReturn(promises.resolve()).when(presenter).setupUsingCurrentSection();
 
         presenter.reset();
@@ -598,7 +539,7 @@ public class SettingsPresenterTest {
 
     @Test
     public void testResetWithoutPermission() {
-        doReturn(false).when(projectController).canUpdateProject(any());
+        doReturn(promises.resolve(false)).when(projectController).canUpdateProject(any());
         doReturn(promises.resolve()).when(presenter).setupUsingCurrentSection();
 
         presenter.reset();
