@@ -25,8 +25,6 @@ import java.util.Set;
 
 import javax.enterprise.event.Event;
 
-import org.ext.uberfire.social.activities.model.ExtendedTypes;
-import org.ext.uberfire.social.activities.model.SocialFileSelectedEvent;
 import org.guvnor.common.services.project.client.context.WorkspaceProjectContext;
 import org.guvnor.common.services.project.context.WorkspaceProjectContextChangeEvent;
 import org.guvnor.common.services.project.model.GAV;
@@ -35,7 +33,7 @@ import org.guvnor.common.services.project.model.POM;
 import org.guvnor.common.services.project.model.Package;
 import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.project.service.WorkspaceProjectService;
-import org.guvnor.common.services.project.social.ModuleEventType;
+import org.guvnor.structure.client.security.OrganizationalUnitController;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
 import org.guvnor.structure.repositories.Branch;
 import org.guvnor.structure.repositories.Repository;
@@ -85,6 +83,7 @@ import org.uberfire.mvp.ParameterizedCommand;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.mvp.impl.DefaultPlaceRequest;
 import org.uberfire.mvp.impl.PathPlaceRequest;
+import org.uberfire.promise.SyncPromises;
 import org.uberfire.rpc.SessionInfo;
 import org.uberfire.spaces.Space;
 import org.uberfire.workbench.events.NotificationEvent;
@@ -242,13 +241,16 @@ public class LibraryPlacesTest {
                                               libraryBreadcrumbs,
                                               sessionInfo,
                                               libraryInternalPreferences,
-                                              repositoryServiceCaller) {
+                                              repositoryServiceCaller,
+                                              new SyncPromises(),
+                                              mock(OrganizationalUnitController.class)) {
 
             @Override
             protected Map<String, List<String>> getParameterMap() {
                 return windowParameters;
             }
         });
+        doNothing().when(libraryPlaces).expose();
         libraryPlaces.setup();
 
         libraryPlaces.init(mock(LibraryPerspective.class));
@@ -554,6 +556,8 @@ public class LibraryPlacesTest {
         doReturn(Optional.empty()).when(projectContext).getActiveWorkspaceProject();
         doReturn(Optional.empty()).when(projectContext).getActiveModule();
 
+        doReturn(mock(OrganizationalUnit.class)).when(libraryService).getDefaultOrganizationalUnit();
+
         final PlaceRequest placeRequest = new DefaultPlaceRequest(LibraryPlaces.LIBRARY_SCREEN);
         final PartDefinitionImpl part = new PartDefinitionImpl(placeRequest);
         part.setSelectable(false);
@@ -793,55 +797,6 @@ public class LibraryPlacesTest {
                never()).setupForProject(any());
     }
 
-    @Test
-    public void testOnSocialFileSelected_Repository() {
-
-        doReturn(mock(WorkspaceProject.class)).when(projectService).resolveProject(any(Path.class));
-
-        doReturn(PlaceStatus.OPEN).when(placeManager).getStatus(LibraryPlaces.LIBRARY_PERSPECTIVE);
-
-        final SocialFileSelectedEvent event = new SocialFileSelectedEvent(ExtendedTypes.NEW_REPOSITORY_EVENT.name(),
-                                                                          null);
-
-        libraryPlaces.onSocialFileSelected(event);
-
-        verify(placeManager).goTo(LibraryPlaces.REPOSITORY_STRUCTURE_SCREEN);
-    }
-
-    @Test
-    public void testOnSocialFileSelected_Module() {
-
-        doReturn(mock(WorkspaceProject.class)).when(projectService).resolveProject(any(Path.class));
-
-        doReturn(PlaceStatus.OPEN).when(placeManager).getStatus(LibraryPlaces.LIBRARY_PERSPECTIVE);
-
-        final PlaceRequest libraryPerspective = libraryPlaces.getLibraryPlaceRequestWithoutRefresh();
-        final SocialFileSelectedEvent event = new SocialFileSelectedEvent(ModuleEventType.NEW_MODULE.name(),
-                                                                          null);
-
-        libraryPlaces.onSocialFileSelected(event);
-
-        verify(placeManager).goTo(libraryPerspective);
-        verify(libraryPlaces).goToProject();
-    }
-
-    @Test
-    public void testOnSocialFileSelected_Asset() {
-
-        doReturn(mock(WorkspaceProject.class)).when(projectService).resolveProject(any(Path.class));
-
-        doReturn(PlaceStatus.OPEN).when(placeManager).getStatus(LibraryPlaces.LIBRARY_PERSPECTIVE);
-
-        final PlaceRequest libraryPerspective = libraryPlaces.getLibraryPlaceRequestWithoutRefresh();
-        final SocialFileSelectedEvent event = new SocialFileSelectedEvent("any",
-                                                                          "uri");
-
-        libraryPlaces.onSocialFileSelected(event);
-
-        verify(placeManager).goTo(libraryPerspective);
-        verify(libraryPlaces).goToAsset(any(Path.class));
-    }
-
     @Test
     public void closeAllPlacesOrNothingWithUncloseablePlacesTest() {
         final Command successCallback = mock(Command.class);
