@@ -16,15 +16,25 @@
 
 package org.kie.workbench.common.stunner.shapes.def;
 
+import org.kie.workbench.common.stunner.core.client.shape.common.DashArray;
+import org.kie.workbench.common.stunner.core.client.shape.view.ShapeView;
 import org.kie.workbench.common.stunner.core.definition.shape.Glyph;
 import org.kie.workbench.common.stunner.core.definition.shape.ShapeDef;
 
-public interface ConnectorShapeDef<W> extends BasicMutableShapeDef<W> {
+public interface ConnectorShapeDef<W, V extends ShapeView>
+        extends BasicShapeViewDef<W, V> {
+
+    String FONT_FAMILY = "Open Sans";
+    String FONT_COLOR = "#000000";
+    String FONT_STROKE_COLOR = "#393f44";
+    double FONT_SIZE = 10d;
+    double STROKE_SIZE = 0.5d;
 
     ConnectorGlyph GLYPH = ConnectorGlyph.create();
 
     @Override
-    default Glyph getGlyph(Class<? extends W> type) {
+    default Glyph getGlyph(Class<? extends W> type,
+                           final String defId) {
         return GLYPH;
     }
 
@@ -32,4 +42,8 @@ public interface ConnectorShapeDef<W> extends BasicMutableShapeDef<W> {
     default Class<? extends ShapeDef> getType() {
         return ConnectorShapeDef.class;
     }
+
+    default DashArray getDashArray(final W element) {
+        return null;
+    }
 }
