@@ -24,5 +24,6 @@ public interface CanvasElementListener extends CanvasListener<CanvasHandler, Ele
     /**
      * An element has been updated on the canvas.
      */
-    void update(final Element item);
+    default void update(Element item) {
+    }
 }
