@@ -16,15 +16,17 @@
 
 package org.kie.workbench.common.stunner.core.client.definition.adapter.binding;
 
+import java.util.Optional;
+
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.powermock.modules.junit4.PowerMockRunner;
 
 import static org.junit.Assert.assertEquals;
 import static org.mockito.Mockito.verify;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(PowerMockRunner.class)
 public class ClientBindableDefinitionAdapterTest extends AbstractClientBindableAdapterTest {
 
     private ClientBindableDefinitionAdapter clientBindableDefinitionAdapter;
@@ -36,6 +38,18 @@ public class ClientBindableDefinitionAdapterTest extends AbstractClientBindableA
 
         clientBindableDefinitionAdapter = new ClientBindableDefinitionAdapter(definitionUtils,
                                                                               translationService);
+
+        clientBindableDefinitionAdapter.setBindings(metaPropertyTypeClasses,
+                                                    baseTypes,
+                                                    propertySetsFieldNames,
+                                                    propertiesFieldNames,
+                                                    propertyGraphFactoryFieldNames,
+                                                    propertyIdFieldNames,
+                                                    propertyLabelsFieldNames,
+                                                    propertyTitleFieldNames,
+                                                    propertyCategoryFieldNames,
+                                                    propertyDescriptionFieldNames,
+                                                    propertyNameFields);
     }
 
     @Test
@@ -54,4 +68,18 @@ public class ClientBindableDefinitionAdapterTest extends AbstractClientBindableA
         assertEquals(DEFINITION_TITLE,
                      title);
     }
+
+    @Test
+    public void testGetProperty() {
+        Optional<?> name = clientBindableDefinitionAdapter.getProperty(model, PROPERTY_NAME);
+
+        assertEquals(name.get(), value);
+    }
+
+    @Test
+    public void testGetNameField() {
+        Optional<?> name = clientBindableDefinitionAdapter.getNameField(model);
+
+        assertEquals(name.get(), PROPERTY_NAME);
+    }
 }
