@@ -38,12 +38,15 @@ import org.mockito.ArgumentCaptor;
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
 import static org.kie.workbench.common.stunner.core.TestingGraphUtils.verifyConnection;
 import static org.kie.workbench.common.stunner.core.TestingGraphUtils.verifyConnectorCardinality;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class AddConnectorCommandTest extends AbstractGraphCommandTest {
@@ -64,8 +67,7 @@ public class AddConnectorCommandTest extends AbstractGraphCommandTest {
 
     @Before
     public void setup() throws Exception {
-        super.init(500,
-                   500);
+        super.init();
         node = mockNode(NODE_UUID);
         sourceMagnet = Optional.of(MagnetConnection.Builder.at(0d,
                                                                0d));
@@ -111,7 +113,7 @@ public class AddConnectorCommandTest extends AbstractGraphCommandTest {
     @Test
     @SuppressWarnings("unchecked")
     public void testAllowNoRules() {
-        when(graphCommandExecutionContext.getRuleManager()).thenReturn(null);
+        useAllowedExecutionContext();
         CommandResult<RuleViolation> result = tested.allow(graphCommandExecutionContext);
         assertEquals(CommandResult.Type.INFO,
                      result.getType());
@@ -130,7 +132,7 @@ public class AddConnectorCommandTest extends AbstractGraphCommandTest {
         assertEquals(edge,
                      node.getOutEdges().get(0));
         verify(graphIndex,
-               times(2)).addEdge(eq(edge));
+               times(1)).addEdge(eq(edge));
         verify(graphIndex,
                times(0)).addNode(any(Node.class));
     }
