@@ -16,6 +16,7 @@
 
 package org.kie.workbench.common.stunner.project.client.editor;
 
+import java.lang.annotation.Annotation;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Objects;
@@ -34,12 +35,18 @@ import com.google.gwt.logging.client.LogConfiguration;
 import com.google.gwt.user.client.ui.IsWidget;
 import com.google.gwt.user.client.ui.ProvidesResize;
 import com.google.gwt.user.client.ui.RequiresResize;
+import elemental2.promise.Promise;
+import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.api.RemoteCallback;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
+import org.kie.workbench.common.stunner.client.widgets.presenters.Viewer;
+import org.kie.workbench.common.stunner.client.widgets.presenters.diagram.DiagramViewer;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.SessionPresenter;
+import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.AbstractSessionPresenter;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionEditorPresenter;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionViewerPresenter;
+import org.kie.workbench.common.stunner.core.api.DefinitionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.CanvasHandler;
 import org.kie.workbench.common.stunner.core.client.error.DiagramClientErrorHandler;
 import org.kie.workbench.common.stunner.core.client.i18n.ClientTranslationService;
@@ -54,6 +61,8 @@ import org.kie.workbench.common.stunner.core.client.shape.Shape;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.diagram.DiagramParsingException;
 import org.kie.workbench.common.stunner.core.diagram.Metadata;
+import org.kie.workbench.common.stunner.core.documentation.DocumentationPage;
+import org.kie.workbench.common.stunner.core.documentation.DocumentationView;
 import org.kie.workbench.common.stunner.core.rule.RuleViolation;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
 import org.kie.workbench.common.stunner.core.validation.DiagramElementViolation;
@@ -77,10 +86,7 @@ import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.client.mvp.PlaceManager;
 import org.uberfire.client.mvp.UberView;
-import org.uberfire.client.workbench.events.AbstractPlaceEvent;
 import org.uberfire.client.workbench.events.ChangeTitleWidgetEvent;
-import org.uberfire.client.workbench.events.PlaceGainFocusEvent;
-import org.uberfire.client.workbench.events.PlaceHiddenEvent;
 import org.uberfire.client.workbench.type.ClientResourceType;
 import org.uberfire.client.workbench.widgets.common.ErrorPopupPresenter;
 import org.uberfire.ext.editor.commons.client.file.popups.SavePopUpPresenter;
@@ -92,49 +98,37 @@ import org.uberfire.mvp.Command;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.mvp.impl.PathPlaceRequest;
 import org.uberfire.workbench.events.NotificationEvent;
-import org.uberfire.workbench.model.menu.Menus;
+
+import static org.kie.workbench.common.stunner.project.client.resources.i18n.StunnerProjectClientConstants.DIAGRAM_PARSING_ERROR;
 
 public abstract class AbstractProjectDiagramEditor<R extends ClientResourceType> extends KieEditor<ProjectDiagramResource> {
 
-    private static Logger LOGGER = Logger.getLogger(AbstractProjectDiagramEditor.class.getName());
+    private static final Logger LOGGER = Logger.getLogger(AbstractProjectDiagramEditor.class.getName());
     private static final String TITLE_FORMAT_TEMPLATE = "#title.#suffix - #type";
-
-    public interface View extends UberView<AbstractProjectDiagramEditor>,
-                                  KieEditorView,
-                                  RequiresResize,
-                                  ProvidesResize,
-                                  IsWidget {
-
-        void setWidget(IsWidget widget);
-    }
-
-    private PlaceManager placeManager;
+    private final ManagedInstance<SessionEditorPresenter<EditorSession>> editorSessionPresenterInstances;
+    private final ManagedInstance<SessionViewerPresenter<ViewerSession>> viewerSessionPresenterInstances;
+    private final DiagramClientErrorHandler diagramClientErrorHandler;
+    private final ClientTranslationService translationService;
+    private final Caller<ProjectDiagramResourceService> projectDiagramResourceServiceCaller;
+    private final TextEditorView xmlEditorView;
+    protected ClientProjectDiagramService projectDiagramServices;
+    protected ProjectDiagramEditorProxy editorProxy = ProjectDiagramEditorProxy.NULL_EDITOR;
     private ErrorPopupPresenter errorPopupPresenter;
     private Event<ChangeTitleWidgetEvent> changeTitleNotificationEvent;
     private R resourceType;
-    protected ClientProjectDiagramService projectDiagramServices;
-    private final ManagedInstance<SessionEditorPresenter<EditorSession>> editorSessionPresenterInstances;
-    private final ManagedInstance<SessionViewerPresenter<ViewerSession>> viewerSessionPresenterInstances;
-    private ProjectEditorMenuSessionItems menuSessionItems;
+    private AbstractProjectEditorMenuSessionItems<?> menuSessionItems;
     private ProjectMessagesListener projectMessagesListener;
-
     private Event<OnDiagramFocusEvent> onDiagramFocusEvent;
     private Event<OnDiagramLoseFocusEvent> onDiagramLostFocusEvent;
     private Optional<SessionEditorPresenter<EditorSession>> editorSessionPresenter = Optional.empty();
     private Optional<SessionViewerPresenter<ViewerSession>> viewerSessionPresenter = Optional.empty();
-    private final DiagramClientErrorHandler diagramClientErrorHandler;
-    private final ClientTranslationService translationService;
-    private final Caller<ProjectDiagramResourceService> projectDiagramResourceServiceCaller;
-
     private String title = "Project Diagram Editor";
-
-    private final TextEditorView xmlEditorView;
-
-    protected ProjectDiagramEditorProxy editorProxy = ProjectDiagramEditorProxy.NULL_EDITOR;
     private boolean menuBarInitialzed = false;
+    private DocumentationView documentationView;
 
     @Inject
     public AbstractProjectDiagramEditor(final View view,
+                                        final DocumentationView documentationView,
                                         final PlaceManager placeManager,
                                         final ErrorPopupPresenter errorPopupPresenter,
                                         final Event<ChangeTitleWidgetEvent> changeTitleNotificationEvent,
@@ -143,7 +137,7 @@ public abstract class AbstractProjectDiagramEditor<R extends ClientResourceType>
                                         final ClientProjectDiagramService projectDiagramServices,
                                         final ManagedInstance<SessionEditorPresenter<EditorSession>> editorSessionPresenterInstances,
                                         final ManagedInstance<SessionViewerPresenter<ViewerSession>> viewerSessionPresenterInstances,
-                                        final ProjectEditorMenuSessionItems menuSessionItems,
+                                        final AbstractProjectEditorMenuSessionItems<?> menuSessionItems,
                                         final Event<OnDiagramFocusEvent> onDiagramFocusEvent,
                                         final Event<OnDiagramLoseFocusEvent> onDiagramLostFocusEvent,
                                         final ProjectMessagesListener projectMessagesListener,
@@ -152,6 +146,7 @@ public abstract class AbstractProjectDiagramEditor<R extends ClientResourceType>
                                         final TextEditorView xmlEditorView,
                                         final Caller<ProjectDiagramResourceService> projectDiagramResourceServiceCaller) {
         super(view);
+        this.documentationView = documentationView;
         this.placeManager = placeManager;
         this.errorPopupPresenter = errorPopupPresenter;
         this.changeTitleNotificationEvent = changeTitleNotificationEvent;
@@ -170,10 +165,6 @@ public abstract class AbstractProjectDiagramEditor<R extends ClientResourceType>
         this.projectDiagramResourceServiceCaller = projectDiagramResourceServiceCaller;
     }
 
-    protected abstract int getCanvasWidth();
-
-    protected abstract int getCanvasHeight();
-
     @PostConstruct
     @SuppressWarnings("unchecked")
     public void init() {
@@ -212,14 +203,20 @@ public abstract class AbstractProjectDiagramEditor<R extends ClientResourceType>
 
     @SuppressWarnings("unchecked")
     public void open(final ProjectDiagram diagram) {
+        open(diagram, Optional.empty());
+    }
+
+    @SuppressWarnings("unchecked")
+    public void open(final ProjectDiagram diagram,
+                     final Optional<SessionPresenter.SessionPresenterCallback<Diagram>> callback) {
         editorProxy = makeStunnerEditorProxy();
         showLoadingViews();
 
         //Open applicable SessionPresenter
         if (!isReadOnly()) {
-            openSession(diagram);
+            openSession(diagram, callback);
         } else {
-            openReadOnlySession(diagram);
+            openReadOnlySession(diagram, callback);
         }
     }
 
@@ -331,70 +328,72 @@ public abstract class AbstractProjectDiagramEditor<R extends ClientResourceType>
         return isReadOnly;
     }
 
-    protected void openSession(final ProjectDiagram diagram) {
-        editorSessionPresenter = Optional.of(newSessionEditorPresenter());
-        editorSessionPresenter.get()
+    private void openSession(final Optional<? extends AbstractSessionPresenter> presenter,
+                             final ProjectDiagram diagram,
+                             final Optional<SessionPresenter.SessionPresenterCallback<Diagram>> callback) {
+        presenter.get()
                 .open(diagram,
                       new SessionPresenter.SessionPresenterCallback<Diagram>() {
                           @Override
                           public void afterSessionOpened() {
-
+                              callback.ifPresent(SessionPresenter.SessionPresenterCallback::afterSessionOpened);
                           }
 
                           @Override
                           public void afterCanvasInitialized() {
-
+                              callback.ifPresent(DiagramViewer.DiagramViewerCallback::afterCanvasInitialized);
                           }
 
                           @Override
                           public void onSuccess() {
                               initialiseKieEditorForSession(diagram);
                               menuSessionItems.bind(getSession());
+                              callback.ifPresent(Viewer.Callback::onSuccess);
                           }
 
                           @Override
                           public void onError(final ClientRuntimeError error) {
                               onLoadError(error);
+                              callback.ifPresent(c -> c.onError(error));
                           }
                       });
     }
 
-    protected void openReadOnlySession(final ProjectDiagram diagram) {
+    protected void openSession(final ProjectDiagram diagram,
+                               final Optional<SessionPresenter.SessionPresenterCallback<Diagram>> callback) {
+        editorSessionPresenter = Optional.of(newSessionEditorPresenter());
+        openSession(editorSessionPresenter, diagram, callback);
+    }
+
+    protected void openReadOnlySession(final ProjectDiagram diagram,
+                                       final Optional<SessionPresenter.SessionPresenterCallback<Diagram>> callback) {
         viewerSessionPresenter = Optional.of(newSessionViewerPresenter());
-        viewerSessionPresenter.get()
-                .open(diagram,
-                      new SessionPresenter.SessionPresenterCallback<Diagram>() {
-                          @Override
-                          public void afterSessionOpened() {
-
-                          }
-
-                          @Override
-                          public void afterCanvasInitialized() {
-
-                          }
-
-                          @Override
-                          public void onSuccess() {
-                              initialiseKieEditorForSession(diagram);
-                              menuSessionItems.bind(getSession());
-                          }
-
-                          @Override
-                          public void onError(final ClientRuntimeError error) {
-                              onLoadError(error);
-                          }
-                      });
+        openSession(viewerSessionPresenter, diagram, callback);
     }
 
     protected void initialiseKieEditorForSession(final ProjectDiagram diagram) {
         resetEditorPages(diagram.getMetadata().getOverview());
         updateTitle(diagram.getMetadata().getTitle());
+        addDocumentationPage(diagram);
         setOriginalHash(getCurrentDiagramHash());
         hideLoadingViews();
         onDiagramLoad();
     }
 
+    protected void addDocumentationPage(ProjectDiagram diagram) {
+        Optional.ofNullable(documentationView.isEnabled())
+                .filter(Boolean.TRUE::equals)
+                .ifPresent(enabled -> {
+                    final String label = translationService.getValue(StunnerProjectClientConstants.DOCUMENTATION);
+                    addPage(new DocumentationPage(documentationView.initialize(diagram),
+                                                  label,
+                                                  //firing the OnDiagramFocusEvent will force the docks to be minimized
+                                                  () -> onDiagramFocusEvent.fire(new OnDiagramFocusEvent(getDockQualifiers())),
+                                                  //check the DocumentationPage is active, the index is 2
+                                                  () -> Objects.equals(2, kieView.getSelectedTabIndex())));
+                });
+    }
+
     protected void onDiagramLoad() {
         /* Override this method to trigger some action after a Diagram is loaded. */
     }
@@ -468,37 +467,54 @@ public abstract class AbstractProjectDiagramEditor<R extends ClientResourceType>
         };
     }
 
-    public void hideDiagramEditorDocks(@Observes PlaceHiddenEvent event) {
-        if (verifyEventIdentifier(event)) {
-            onDiagramLostFocusEvent.fire(new OnDiagramLoseFocusEvent());
-        }
-    }
-
-    public void showDiagramEditorDocks(@Observes PlaceGainFocusEvent event) {
-        if (verifyEventIdentifier(event)) {
-            onDiagramFocusEvent.fire(new OnDiagramFocusEvent());
-        }
+    @Override
+    public void hideDocks() {
+        super.hideDocks();
+        onDiagramLostFocusEvent.fire(new OnDiagramLoseFocusEvent());
     }
 
     @Override
-    protected void makeMenuBar() {
+    public void showDocks() {
+        // Docks are shown by AppFormer before the session/diagram has been opened. It is therefore impossible to use
+        // the ideal getDiagram().getMetadata().getDefinitionSetId() and use that as the qualifier for docks.
+        onDiagramFocusEvent.fire(new OnDiagramFocusEvent(getDockQualifiers()));
+        super.showDocks();
+    }
+
+    public Annotation[] getDockQualifiers() {
+        return new Annotation[]{DefinitionManager.DEFAULT_QUALIFIER};
+    }
+
+    @Override
+    protected Promise<Void> makeMenuBar() {
         if (!menuBarInitialzed) {
             menuSessionItems.populateMenu(fileMenuBuilder);
             makeAdditionalStunnerMenus(fileMenuBuilder);
-            if (canUpdateProject()) {
-                fileMenuBuilder
-                        .addSave(versionRecordManager.newSaveMenuItem(this::saveAction))
-                        .addCopy(versionRecordManager.getCurrentPath(),
-                                 assetUpdateValidator)
-                        .addRename(getSaveAndRename())
-                        .addDelete(versionRecordManager.getPathToLatest(),
-                                   assetUpdateValidator);
+            if (workbenchContext.getActiveWorkspaceProject().isPresent()) {
+                final WorkspaceProject activeProject = workbenchContext.getActiveWorkspaceProject().get();
+                return projectController.canUpdateProject(activeProject).then(canUpdateProject -> {
+                    if (canUpdateProject) {
+                        fileMenuBuilder
+                                .addSave(versionRecordManager.newSaveMenuItem(this::saveAction))
+                                .addCopy(versionRecordManager.getCurrentPath(),
+                                         assetUpdateValidator)
+                                .addRename(getSaveAndRename())
+                                .addDelete(versionRecordManager.getPathToLatest(),
+                                           assetUpdateValidator);
+                    }
+
+                    addDownloadMenuItem(fileMenuBuilder);
+
+                    fileMenuBuilder
+                            .addNewTopLevelMenu(versionRecordManager.buildMenu())
+                            .addNewTopLevelMenu(alertsButtonMenuItemBuilder.build());
+                    menuBarInitialzed = true;
+
+                    return promises.resolve();
+                });
             }
-            fileMenuBuilder
-                    .addNewTopLevelMenu(versionRecordManager.buildMenu())
-                    .addNewTopLevelMenu(alertsButtonMenuItemBuilder.build());
-            menuBarInitialzed = true;
         }
+        return promises.resolve();
     }
 
     @Override
@@ -566,23 +582,14 @@ public abstract class AbstractProjectDiagramEditor<R extends ClientResourceType>
         }
     }
 
-    private boolean isSameSession(final ClientSession other) {
+    protected boolean isSameSession(final ClientSession other) {
         return null != other && null != getSession() && other.equals(getSession());
     }
 
-    protected abstract String getEditorIdentifier();
-
     public String getTitleText() {
         return title;
     }
 
-    protected Menus getMenus() {
-        if (menus == null) {
-            makeMenuBar();
-        }
-        return menus;
-    }
-
     @Override
     protected void onSave() {
         if (hasUnsavedChanges()) {
@@ -716,6 +723,8 @@ public abstract class AbstractProjectDiagramEditor<R extends ClientResourceType>
             getView().setWidget(xmlEditorView.asWidget());
             editorProxy = makeXmlEditorProxy();
             hideLoadingViews();
+            notification.fire(new NotificationEvent(getDiagramParsingErrorMessage(dpe),
+                                                    NotificationEvent.NotificationType.ERROR));
 
             Scheduler.get().scheduleDeferred(xmlEditorView::onResize);
         } else {
@@ -728,6 +737,10 @@ public abstract class AbstractProjectDiagramEditor<R extends ClientResourceType>
         }
     }
 
+    protected String getDiagramParsingErrorMessage(final DiagramParsingException e) {
+        return translationService.getValue(DIAGRAM_PARSING_ERROR, Objects.toString(e.getMessage(), ""));
+    }
+
     protected void showError(final ClientRuntimeError error) {
         diagramClientErrorHandler.handleError(error, this::showError);
         log(Level.SEVERE, error.toString());
@@ -750,13 +763,6 @@ public abstract class AbstractProjectDiagramEditor<R extends ClientResourceType>
         return getCurrentDiagramHash() != originalHash;
     }
 
-    private boolean verifyEventIdentifier(AbstractPlaceEvent event) {
-        return (Objects.equals(getEditorIdentifier(),
-                               event.getPlace().getIdentifier()) &&
-                Objects.equals(place,
-                               event.getPlace()));
-    }
-
     protected ClientTranslationService getTranslationService() {
         return translationService;
     }
@@ -773,7 +779,7 @@ public abstract class AbstractProjectDiagramEditor<R extends ClientResourceType>
         return null;
     }
 
-    public ProjectEditorMenuSessionItems getMenuSessionItems() {
+    public AbstractProjectEditorMenuSessionItems getMenuSessionItems() {
         return menuSessionItems;
     }
 
@@ -786,4 +792,13 @@ public abstract class AbstractProjectDiagramEditor<R extends ClientResourceType>
     protected void setReadOnlySessionPresenter(final SessionViewerPresenter<ViewerSession> presenter) {
         this.viewerSessionPresenter = Optional.ofNullable(presenter);
     }
+
+    public interface View extends UberView<AbstractProjectDiagramEditor>,
+                                  KieEditorView,
+                                  RequiresResize,
+                                  ProvidesResize,
+                                  IsWidget {
+
+        void setWidget(IsWidget widget);
+    }
 }
