@@ -21,8 +21,9 @@ import java.util.HashMap;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
-import java.util.stream.IntStream;
+import java.util.stream.Collectors;
 
+import org.kie.workbench.common.stunner.client.lienzo.shape.impl.ShapeStateDefaultHandler;
 import org.kie.workbench.common.stunner.svg.client.shape.view.SVGShapeView;
 import org.kie.workbench.common.stunner.svg.gen.codegen.PrimitiveDefinitionGenerator;
 import org.kie.workbench.common.stunner.svg.gen.codegen.ViewDefinitionGenerator;
@@ -30,11 +31,11 @@ import org.kie.workbench.common.stunner.svg.gen.exception.GeneratorException;
 import org.kie.workbench.common.stunner.svg.gen.model.LayoutDefinition;
 import org.kie.workbench.common.stunner.svg.gen.model.PrimitiveDefinition;
 import org.kie.workbench.common.stunner.svg.gen.model.ShapeDefinition;
-import org.kie.workbench.common.stunner.svg.gen.model.ShapePolicyDefinition;
 import org.kie.workbench.common.stunner.svg.gen.model.StyleSheetDefinition;
 import org.kie.workbench.common.stunner.svg.gen.model.ViewDefinition;
 import org.kie.workbench.common.stunner.svg.gen.model.ViewFactory;
 import org.kie.workbench.common.stunner.svg.gen.model.ViewRefDefinition;
+import org.kie.workbench.common.stunner.svg.gen.model.impl.SVGModelUtils;
 import org.kie.workbench.common.stunner.svg.gen.model.impl.ViewDefinitionImpl;
 import org.uberfire.annotations.processors.exceptions.GenerationException;
 
@@ -42,44 +43,36 @@ public class SVGViewDefinitionGenerator
         extends AbstractGenerator
         implements ViewDefinitionGenerator<ViewDefinition<SVGShapeView>> {
 
-    private static final String CHILD_OBJECT_ID = "child";
     public static final String PRIM_CHILD_TEMPLATE = "view.addChild(%1s);";
     private static final String SVG_CHILD_TEMPLATE = "view.addSVGChild(%1s, %1s.this.%1sBasicView());";
 
     @Override
+    @SuppressWarnings("unchecked")
     public StringBuffer generate(final ViewFactory viewFactory,
                                  final ViewDefinition<SVGShapeView> viewDefinition) throws GeneratorException {
         StringBuffer result = null;
         final String factoryName = viewFactory.getSimpleName();
         final String viewId = viewDefinition.getId();
         final String methodName = viewDefinition.getFactoryMethodName();
-        final double x = viewDefinition.getX();
-        final double y = viewDefinition.getY();
-        final double width = viewDefinition.getWidth();
-        final double height = viewDefinition.getHeight();
         final ShapeDefinition main = viewDefinition.getMain();
-        final ViewDefinition.ViewBoxDefinition viewBox = viewDefinition.getViewBox();
         if (null != main) {
-            final Map<String, Object> root = new HashMap<String, Object>();
+            final Map<String, Object> root = new HashMap<>();
 
             // Generate the children primitives.
             final List<String> childrenRaw = new LinkedList<>();
             final List<PrimitiveDefinition> children = viewDefinition.getChildren();
-            for (int i = 0; i < children.size(); i++) {
-                final PrimitiveDefinition child = children.get(i);
-                final String childId = CHILD_OBJECT_ID + i;
+            for (final PrimitiveDefinition child : children) {
+                final String childId = SVGGeneratorFormatUtils.getValidInstanceId(child);
                 String childRaw =
                         SVGPrimitiveGeneratorUtils
                                 .generateSvgPrimitive(childId,
                                                       SVGViewDefinitionGenerator::getGenerator,
                                                       child);
                 if (null != childRaw) {
-                    childRaw += AbstractGenerator.formatString(PRIM_CHILD_TEMPLATE,
-                                                               childId);
-                } else {
-                    childRaw = "";
+                    childrenRaw.add(childRaw);
+                    childrenRaw.add(AbstractGenerator.formatString(PRIM_CHILD_TEMPLATE,
+                                                                   childId));
                 }
-                childrenRaw.add(childRaw);
             }
 
             // SVG View children.
@@ -87,10 +80,6 @@ public class SVGViewDefinitionGenerator
             final List<ViewRefDefinition> svgViewRefs = viewDefinition.getSVGViewRefs();
             svgViewRefs.forEach(viewRef -> {
                 final String parent = viewRef.getParent();
-                final int parentIndex = getChildrenIndex(viewDefinition, parent);
-                if (parentIndex < 0) {
-                    throw new IllegalArgumentException("No parent found with id [" + parent + "]");
-                }
                 final String svgName = viewRef.getFilePath();
                 final String viewRefId = viewRef.getViewRefId();
                 final boolean existReferencedView = viewFactory
@@ -98,7 +87,7 @@ public class SVGViewDefinitionGenerator
                         .anyMatch(def -> viewRefId.equals(def.getId()));
                 if (existReferencedView) {
                     final String childRaw = formatString(SVG_CHILD_TEMPLATE,
-                                                         CHILD_OBJECT_ID + parentIndex,
+                                                         parent,
                                                          factoryName,
                                                          viewRefId);
                     svgChildrenRaw.add(childRaw);
@@ -109,18 +98,31 @@ public class SVGViewDefinitionGenerator
                 }
             });
 
+            // Look for the state shape view.
+            final List<ShapeDefinition> stateViews = new LinkedList<>();
+            SVGModelUtils.visit(viewDefinition,
+                                p -> {
+                                    if (p instanceof ShapeDefinition &&
+                                            SVGPrimitiveGeneratorUtils.CAN_GENERATE_PRIMITIVE_CODE.test(p)) {
+                                        final ShapeDefinition shapeDefinition = (ShapeDefinition) p;
+                                        shapeDefinition.getStateDefinition()
+                                                .ifPresent(s -> stateViews.add((ShapeDefinition) p));
+                                    }
+                                });
+
+            final String stateViewIds = stateViews.isEmpty() ? "view" : stateViews.stream()
+                    .map(d -> SVGGeneratorFormatUtils.getValidInstanceId(d.getId()))
+                    .collect(Collectors.joining(","));
+            final String stateViewPolicyType = stateViews.isEmpty() ?
+                    ShapeStateDefaultHandler.RenderType.STROKE.name() :
+                    ((ShapeDefinition.ShapeStateDefinition) stateViews.get(0).getStateDefinition().get()).name();
+            final String stateViewPolicy = ShapeStateDefaultHandler.RenderType.class.getName().replace("$", ".") +
+                    "." + stateViewPolicyType.toUpperCase();
             // Generate the main shape.
             final PrimitiveDefinitionGenerator<PrimitiveDefinition<?>> mainGenerator = getGenerator(main);
             final StringBuffer mainBuffer = mainGenerator.generate(main);
             final LayoutDefinition mainLayoutDefinition = main.getLayoutDefinition();
             final String mainLayoutRaw = SVGPrimitiveGeneratorUtils.formatLayout(mainLayoutDefinition);
-            final ShapePolicyDefinition policy = main.getShapePolicyDefinition();
-            final String mainPolicyRaw = SVGPrimitiveGeneratorUtils.formatShapePolicy(policy);
-
-            // Generate the view shape states styling stuff.
-            final String shapeStateHoldersRaw =
-                    SVGShapeStateHolderCodeBuilder.generateStateHolders("view",
-                                                                        viewDefinition.getShapeStateDefinition());
 
             // Generate the view's text styling stuff.
             final StyleSheetDefinition globalStyleSheetDefinition =
@@ -139,16 +141,16 @@ public class SVGViewDefinitionGenerator
                      mainBuffer.toString());
             root.put("layout",
                      mainLayoutRaw);
-            root.put("policy",
-                     mainPolicyRaw);
             root.put("width",
                      formatDouble(viewDefinition.getWidth()));
             root.put("height",
                      formatDouble(viewDefinition.getHeight()));
-            root.put("stateHolders",
-                     shapeStateHoldersRaw);
             root.put("text",
                      viewTextRaw);
+            root.put("stateViewIds",
+                     stateViewIds);
+            root.put("stateViewPolicy",
+                     stateViewPolicy);
             root.put("children",
                      childrenRaw);
             root.put("svgChildren",
@@ -163,19 +165,10 @@ public class SVGViewDefinitionGenerator
         return result;
     }
 
-    private static int getChildrenIndex(final ViewDefinition<SVGShapeView> viewDefinition,
-                                        final String id) {
-        final List<PrimitiveDefinition> children = viewDefinition.getChildren();
-        return IntStream.range(0, children.size())
-                .filter(i -> id.equals(children.get(i).getId()))
-                .findFirst()
-                .orElse(-1);
-    }
-
     @SuppressWarnings("unchecked")
     private static PrimitiveDefinitionGenerator<PrimitiveDefinition<?>> getGenerator(final PrimitiveDefinition main) {
         final PrimitiveDefinitionGenerator<?>[] array = ViewGenerators.newPrimitiveDefinitionGenerators();
-        final List<PrimitiveDefinitionGenerator<?>> list = new LinkedList<PrimitiveDefinitionGenerator<?>>();
+        final List<PrimitiveDefinitionGenerator<?>> list = new LinkedList<>();
         Collections.addAll(list,
                            array);
         return (PrimitiveDefinitionGenerator<PrimitiveDefinition<?>>) list.stream()
