@@ -18,54 +18,54 @@ package org.kie.workbench.common.stunner.bpmn.definition;
 
 import java.util.Objects;
 
+import javax.validation.Valid;
+
 import org.jboss.errai.common.client.api.annotations.MapsTo;
-import org.jboss.errai.common.client.api.annotations.NonPortable;
 import org.jboss.errai.common.client.api.annotations.Portable;
 import org.jboss.errai.databinding.client.api.Bindable;
+import org.kie.workbench.common.forms.adf.definitions.annotations.FieldParam;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormDefinition;
+import org.kie.workbench.common.forms.adf.definitions.annotations.FormField;
 import org.kie.workbench.common.forms.adf.definitions.settings.FieldPolicy;
 import org.kie.workbench.common.stunner.bpmn.definition.property.background.BackgroundSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.CircleDimensionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Radius;
-import org.kie.workbench.common.stunner.bpmn.definition.property.event.IsInterrupting;
+import org.kie.workbench.common.stunner.bpmn.definition.property.event.BaseStartEventExecutionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.BPMNGeneralSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.SimulationAttributeSet;
 import org.kie.workbench.common.stunner.core.definition.annotation.Definition;
-import org.kie.workbench.common.stunner.core.definition.annotation.Property;
+import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
 import org.kie.workbench.common.stunner.core.definition.annotation.morph.Morph;
-import org.kie.workbench.common.stunner.core.definition.builder.Builder;
 import org.kie.workbench.common.stunner.core.factory.graph.NodeFactory;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
 
+import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.processing.fields.fieldInitializers.nestedForms.SubFormFieldInitializer.COLLAPSIBLE_CONTAINER;
+import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.processing.fields.fieldInitializers.nestedForms.SubFormFieldInitializer.FIELD_CONTAINER_PARAM;
+
 @Portable
 @Bindable
-@Definition(graphFactory = NodeFactory.class, builder = StartNoneEvent.StartNoneEventBuilder.class)
+@Definition(graphFactory = NodeFactory.class)
 @Morph(base = BaseStartEvent.class)
 @FormDefinition(
         startElement = "general",
-        policy = FieldPolicy.ONLY_MARKED
+        policy = FieldPolicy.ONLY_MARKED,
+        defaultFieldSettings = {@FieldParam(name = FIELD_CONTAINER_PARAM, value = COLLAPSIBLE_CONTAINER)}
 )
 public class StartNoneEvent extends BaseStartEvent {
 
-    @Property
-    private IsInterrupting isInterrupting = new IsInterrupting(true);
-
-    @NonPortable
-    public static class StartNoneEventBuilder implements Builder<StartNoneEvent> {
-
-        @Override
-        public StartNoneEvent build() {
-            return new StartNoneEvent(new BPMNGeneralSet(""),
-                                      new BackgroundSet(),
-                                      new FontSet(),
-                                      new CircleDimensionSet(new Radius()),
-                                      new SimulationAttributeSet(),
-                                      new IsInterrupting(true));
-        }
-    }
+    @PropertySet
+    @FormField(afterElement = "general")
+    @Valid
+    protected BaseStartEventExecutionSet executionSet;
 
     public StartNoneEvent() {
+        this(new BPMNGeneralSet(""),
+             new BackgroundSet(),
+             new FontSet(),
+             new CircleDimensionSet(new Radius()),
+             new SimulationAttributeSet(),
+             new BaseStartEventExecutionSet());
     }
 
     public StartNoneEvent(final @MapsTo("general") BPMNGeneralSet general,
@@ -73,27 +73,27 @@ public class StartNoneEvent extends BaseStartEvent {
                           final @MapsTo("fontSet") FontSet fontSet,
                           final @MapsTo("dimensionsSet") CircleDimensionSet dimensionsSet,
                           final @MapsTo("simulationSet") SimulationAttributeSet simulationSet,
-                          final @MapsTo("isInterrupting") IsInterrupting isInterrupting) {
+                          final @MapsTo("executionSet") BaseStartEventExecutionSet executionSet) {
         super(general,
               backgroundSet,
               fontSet,
               dimensionsSet,
               simulationSet);
-        this.isInterrupting = isInterrupting;
+        this.executionSet = executionSet;
     }
 
-    public IsInterrupting getIsInterrupting() {
-        return isInterrupting;
+    public BaseStartEventExecutionSet getExecutionSet() {
+        return executionSet;
     }
 
-    public void setIsInterrupting(IsInterrupting isInterrupting) {
-        this.isInterrupting = isInterrupting;
+    public void setExecutionSet(BaseStartEventExecutionSet executionSet) {
+        this.executionSet = executionSet;
     }
 
     @Override
     public int hashCode() {
         return HashUtil.combineHashCodes(super.hashCode(),
-                                         Objects.hashCode(isInterrupting));
+                                         Objects.hashCode(executionSet));
     }
 
     @Override
@@ -101,8 +101,7 @@ public class StartNoneEvent extends BaseStartEvent {
         if (o instanceof StartNoneEvent) {
             StartNoneEvent other = (StartNoneEvent) o;
             return super.equals(other) &&
-                    Objects.equals(isInterrupting,
-                                   other.isInterrupting);
+                    Objects.equals(executionSet, other.executionSet);
         }
         return false;
     }
