@@ -37,7 +37,6 @@ import com.fasterxml.jackson.core.Version;
 import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.oryx.OryxManager;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNDefinition;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNDiagram;
-import org.kie.workbench.common.stunner.bpmn.factory.BPMNGraphFactory;
 import org.kie.workbench.common.stunner.core.api.DefinitionManager;
 import org.kie.workbench.common.stunner.core.api.FactoryManager;
 import org.kie.workbench.common.stunner.core.command.Command;
@@ -46,27 +45,33 @@ import org.kie.workbench.common.stunner.core.command.CommandResult;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Graph;
 import org.kie.workbench.common.stunner.core.graph.Node;
-import org.kie.workbench.common.stunner.core.graph.command.EmptyRulesCommandExecutionContext;
+import org.kie.workbench.common.stunner.core.graph.command.DirectGraphCommandExecutionContext;
 import org.kie.workbench.common.stunner.core.graph.command.GraphCommandExecutionContext;
 import org.kie.workbench.common.stunner.core.graph.command.impl.GraphCommandFactory;
 import org.kie.workbench.common.stunner.core.graph.content.definition.DefinitionSet;
-import org.kie.workbench.common.stunner.core.graph.content.view.BoundImpl;
-import org.kie.workbench.common.stunner.core.graph.content.view.BoundsImpl;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
 import org.kie.workbench.common.stunner.core.graph.processing.index.GraphIndexBuilder;
 import org.kie.workbench.common.stunner.core.graph.processing.index.Index;
+import org.kie.workbench.common.stunner.core.registry.impl.DefinitionsCacheRegistry;
 import org.kie.workbench.common.stunner.core.rule.RuleManager;
 import org.kie.workbench.common.stunner.core.rule.RuleViolation;
 import org.kie.workbench.common.stunner.core.util.UUID;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
+import static org.kie.workbench.common.stunner.core.definition.adapter.binding.BindableAdapterUtils.getDefinitionSetId;
 
 /**
  * Support for a basic single process hierarchy
  */
 public class BPMNGraphGenerator extends JsonGenerator {
 
+    private static final Logger LOG = LoggerFactory.getLogger(BPMNGraphGenerator.class);
+
     private final GraphObjectBuilderFactory bpmnGraphBuilderFactory;
     private final DefinitionManager definitionManager;
     private final FactoryManager factoryManager;
+    private final DefinitionsCacheRegistry definitionsCacheRegistry;
     private final RuleManager ruleManager;
     private final OryxManager oryxManager;
     private final CommandManager<GraphCommandExecutionContext, RuleViolation> commandManager;
@@ -83,6 +88,7 @@ public class BPMNGraphGenerator extends JsonGenerator {
     public BPMNGraphGenerator(final GraphObjectBuilderFactory bpmnGraphBuilderFactory,
                               final DefinitionManager definitionManager,
                               final FactoryManager factoryManager,
+                              final DefinitionsCacheRegistry definitionsCacheRegistry,
                               final RuleManager ruleManager,
                               final OryxManager oryxManager,
                               final CommandManager<GraphCommandExecutionContext, RuleViolation> commandManager,
@@ -93,6 +99,7 @@ public class BPMNGraphGenerator extends JsonGenerator {
         this.bpmnGraphBuilderFactory = bpmnGraphBuilderFactory;
         this.definitionManager = definitionManager;
         this.factoryManager = factoryManager;
+        this.definitionsCacheRegistry = definitionsCacheRegistry;
         this.ruleManager = ruleManager;
         this.oryxManager = oryxManager;
         this.commandManager = commandManager;
@@ -147,16 +154,7 @@ public class BPMNGraphGenerator extends JsonGenerator {
 
     public Graph<DefinitionSet, Node> createGraph() {
         Graph<DefinitionSet, Node> graph = (Graph<DefinitionSet, Node>) factoryManager.newElement(UUID.uuid(),
-                                                                                                  diagramDefinitionSetClass);
-        // TODO: Where are the BPMN diagram bounds in the Oryx json structure? Exist?
-        if (null == graph.getContent().getBounds()) {
-            graph.getContent().setBounds(new BoundsImpl(
-                    new BoundImpl(0d,
-                                  0d),
-                    new BoundImpl(BPMNGraphFactory.GRAPH_DEFAULT_WIDTH,
-                                  BPMNGraphFactory.GRAPH_DEFAULT_HEIGHT)
-            ));
-        }
+                                                                                                  getDefinitionSetId(diagramDefinitionSetClass));
         builderContext
                 // Initialize the builder context.
                 .init(graph)
@@ -225,6 +223,11 @@ public class BPMNGraphGenerator extends JsonGenerator {
             return factoryManager;
         }
 
+        @Override
+        public DefinitionsCacheRegistry getDefinitionsRegistry() {
+            return definitionsCacheRegistry;
+        }
+
         @Override
         public OryxManager getOryxManager() {
             return oryxManager;
@@ -233,10 +236,9 @@ public class BPMNGraphGenerator extends JsonGenerator {
         @SuppressWarnings("unchecked")
         public CommandResult<RuleViolation> execute(final Command<GraphCommandExecutionContext, RuleViolation> command) {
             GraphCommandExecutionContext executionContext =
-                    new EmptyRulesCommandExecutionContext(definitionManager,
-                                                          factoryManager,
-                                                          ruleManager,
-                                                          index);
+                    new DirectGraphCommandExecutionContext(definitionManager,
+                                                           factoryManager,
+                                                           index);
             return commandManager.execute(executionContext,
                                           command);
         }
@@ -248,9 +250,9 @@ public class BPMNGraphGenerator extends JsonGenerator {
 
     // For local testing...
     private void logBuilders() {
-        log("Logging builders at creation time...");
+        LOG.debug("Logging builders at creation time...");
         for (GraphObjectBuilder<?, ?> builder : builders) {
-            log(builder.toString());
+            LOG.debug("{}", builder);
         }
     }
 
@@ -591,10 +593,6 @@ public class BPMNGraphGenerator extends JsonGenerator {
         }
     }
 
-    private void log(final String message) {
-        System.out.println(message);
-    }
-
     /***********************************************************************************
      * NOT IMPLEMENTED METHODS.
      ***********************************************************************************/
