@@ -49,12 +49,15 @@ import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.oryx.property
 import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.oryx.property.DoubleTypeSerializer;
 import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.oryx.property.EnumTypeSerializer;
 import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.oryx.property.IntegerTypeSerializer;
+import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.oryx.property.NotificationsTypeSerializer;
+import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.oryx.property.ReassignmentsTypeSerializer;
 import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.oryx.property.ScriptTypeListTypeSerializer;
 import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.oryx.property.ScriptTypeTypeSerializer;
 import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.oryx.property.StringTypeSerializer;
 import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.oryx.property.TaskTypeSerializer;
 import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.oryx.property.TimerSettingsTypeSerializer;
 import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.oryx.property.VariablesTypeSerializer;
+import org.kie.workbench.common.stunner.bpmn.backend.service.diagram.MigrationDiagramMarshallerTest;
 import org.kie.workbench.common.stunner.bpmn.backend.service.diagram.MockApplicationFactoryManager;
 import org.kie.workbench.common.stunner.bpmn.backend.service.diagram.TaskTypeMorphDefinition;
 import org.kie.workbench.common.stunner.bpmn.backend.service.diagram.Unmarshalling;
@@ -64,6 +67,7 @@ import org.kie.workbench.common.stunner.bpmn.definition.BusinessRuleTask;
 import org.kie.workbench.common.stunner.bpmn.definition.NoneTask;
 import org.kie.workbench.common.stunner.bpmn.definition.ScriptTask;
 import org.kie.workbench.common.stunner.bpmn.definition.UserTask;
+import org.kie.workbench.common.stunner.bpmn.workitem.ServiceTask;
 import org.kie.workbench.common.stunner.core.api.DefinitionManager;
 import org.kie.workbench.common.stunner.core.api.FactoryManager;
 import org.kie.workbench.common.stunner.core.backend.definition.adapter.bind.BackendBindableMorphAdapter;
@@ -109,6 +113,7 @@ import org.kie.workbench.common.stunner.core.rule.RuleSet;
 import org.kie.workbench.common.stunner.core.rule.violations.DefaultRuleViolations;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
 import org.mockito.Mock;
+import org.mockito.Spy;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
@@ -136,6 +141,9 @@ public abstract class BPMNDiagramMarshallerBase {
     private CloneManager cloneManager;
     @Mock
     private FactoryManager applicationFactoryManager;
+    @Spy
+    protected GraphCommandManager commandManager =
+            new GraphCommandManagerImpl(null, null, null);
 
     private EdgeFactory<Object> connectionEdgeFactory;
     private NodeFactory<Object> viewNodeFactory;
@@ -162,7 +170,6 @@ public abstract class BPMNDiagramMarshallerBase {
         when(definitionManager.adapters()).thenReturn(adapterManager);
         when(adapterManager.registry()).thenReturn(adapterRegistry);
         DefinitionUtils definitionUtils1 = new DefinitionUtils(definitionManager,
-                                                               applicationFactoryManager,
                                                                null); // TODO!
         testScopeModelFactory = new TestScopeModelFactory(new BPMNDefinitionSet.BPMNDefinitionSetBuilder().build());
         // Definition manager.
@@ -209,9 +216,8 @@ public abstract class BPMNDiagramMarshallerBase {
                                                       anyString());
         doAnswer(invocationOnMock -> {
             String uuid = (String) invocationOnMock.getArguments()[0];
-            Class type = (Class) invocationOnMock.getArguments()[1];
-            String id = BindableAdapterUtils.getGenericClassName(type);
-            if (BPMNDefinitionSet.class.equals(type)) {
+            String id = (String) invocationOnMock.getArguments()[1];
+            if (BindableAdapterUtils.getDefinitionSetId(BPMNDefinitionSet.class).equals(id)) {
                 return bpmnGraphFactory.build(uuid, BPMN_DEF_SET_ID);
             }
             Object model = testScopeModelFactory.accepts(id) ? testScopeModelFactory.build(id) : null;
@@ -225,7 +231,7 @@ public abstract class BPMNDiagramMarshallerBase {
             }
             return null;
         }).when(applicationFactoryManager).newElement(anyString(),
-                                                      any(Class.class));
+                                                      anyString());
         doAnswer(invocationOnMock -> {
             String uuid = (String) invocationOnMock.getArguments()[0];
             String defSetId = (String) invocationOnMock.getArguments()[1];
@@ -248,6 +254,8 @@ public abstract class BPMNDiagramMarshallerBase {
         IntegerTypeSerializer integerTypeSerializer = new IntegerTypeSerializer();
         EnumTypeSerializer enumTypeSerializer = new EnumTypeSerializer(definitionUtils1);
         AssignmentsTypeSerializer assignmentsTypeSerializer = new AssignmentsTypeSerializer();
+        NotificationsTypeSerializer notificationsTypeSerializer = new NotificationsTypeSerializer();
+        ReassignmentsTypeSerializer reassignmentsTypeSerializer = new ReassignmentsTypeSerializer();
         VariablesTypeSerializer variablesTypeSerializer = new VariablesTypeSerializer();
         TimerSettingsTypeSerializer timerSettingsTypeSerializer = new TimerSettingsTypeSerializer();
         ScriptTypeTypeSerializer scriptTypeTypeSerializer = new ScriptTypeTypeSerializer();
@@ -262,6 +270,8 @@ public abstract class BPMNDiagramMarshallerBase {
         propertySerializers.add(integerTypeSerializer);
         propertySerializers.add(enumTypeSerializer);
         propertySerializers.add(assignmentsTypeSerializer);
+        propertySerializers.add(notificationsTypeSerializer);
+        propertySerializers.add(reassignmentsTypeSerializer);
         propertySerializers.add(variablesTypeSerializer);
         propertySerializers.add(timerSettingsTypeSerializer);
         propertySerializers.add(scriptTypeTypeSerializer);
@@ -288,6 +298,7 @@ public abstract class BPMNDiagramMarshallerBase {
         when(adapterRegistry.getMorphAdapter(eq(NoneTask.class))).thenReturn(morphAdapter);
         when(adapterRegistry.getMorphAdapter(eq(ScriptTask.class))).thenReturn(morphAdapter);
         when(adapterRegistry.getMorphAdapter(eq(BusinessRuleTask.class))).thenReturn(morphAdapter);
+        when(adapterRegistry.getMorphAdapter(eq(ServiceTask.class))).thenReturn(morphAdapter);
         GraphIndexBuilder<?> indexBuilder = new MapIndexBuilder();
         when(rulesManager.evaluate(any(RuleSet.class),
                                    any(RuleEvaluationContext.class))).thenReturn(new DefaultRuleViolations());
@@ -315,7 +326,6 @@ public abstract class BPMNDiagramMarshallerBase {
                                    any(RuleEvaluationContext.class))).thenReturn(new DefaultRuleViolations());
 
         DefinitionUtils definitionUtils = new DefinitionUtils(definitionManager,
-                                                              applicationFactoryManager,
                                                               null); // TODO!
         TestScopeModelFactory testScopeModelFactory = new TestScopeModelFactory(new BPMNDefinitionSet.BPMNDefinitionSetBuilder().build());
         // Definition manager.
@@ -329,9 +339,6 @@ public abstract class BPMNDiagramMarshallerBase {
                 new NodeFactoryImpl(definitionUtils)
         );
 
-        GraphCommandManagerImpl commandManager = new GraphCommandManagerImpl(null,
-                                                                             null,
-                                                                             null);
         GraphCommandFactory commandFactory = new GraphCommandFactory();
 
         // The tested BPMN marshaller.
@@ -407,12 +414,6 @@ public abstract class BPMNDiagramMarshallerBase {
             Bounds oldBounds = oldContent.getBounds();
             Bounds newBounds = newContent.getBounds();
 
-            assertEquals(
-                    fileName + ": Bounds should match for " + o.getUUID(),
-                    oldBounds,
-                    newBounds
-            );
-
             Object oldDefinition = oldContent.getDefinition();
             Object newDefinition = newContent.getDefinition();
 
@@ -421,6 +422,14 @@ public abstract class BPMNDiagramMarshallerBase {
                     oldDefinition,
                     newDefinition
             );
+
+            if (!MigrationDiagramMarshallerTest.areBoundsFixed(newDefinition)) {
+                assertEquals(
+                        fileName + ": Bounds should match for " + o.getUUID(),
+                        oldBounds,
+                        newBounds
+                );
+            }
         }
     }
 
